----------------------------------------------------------------
-- Script para crear la tabla CENTRAL_DISTRIBUCION 
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			CENTRAL_DISTRIBUCION
	
	Funcionalidad:				Almacenar las centrales de distribución, 
								que relacionan los contadores con las centrales de producción

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/

CREATE TABLE CENTRAL_DISTRIBUCION 
(
  COD_CENTRAL NUMBER(12, 0) NOT NULL 
, DIRECCION VARCHAR2(40 BYTE) 
, LOCALIDAD VARCHAR2(15 BYTE) 
, PAIS VARCHAR2(15 BYTE) 
, COD_LINEA NUMBER(12, 0) NOT NULL 
, ENERGIA_MAX NUMBER(20, 2) NOT NULL 
, ULTIMA_INSPECCION DATE 
, CONSTRAINT CENTRAL_DISTRIBUCION_PK PRIMARY KEY 
  (
    COD_CENTRAL 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla CENTRAL_PRODUCCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla :		CENTRAL_PRODUCCION
	
	Funcionalidad:				Almacenar los datos principales de las centrales de producción

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE TABLE CENTRAL_PRODUCCION 
(
  COD_CENTRAL NUMBER(12, 0) NOT NULL 
, DIRECCION VARCHAR2(40) 
, LOCALIDAD VARCHAR2(15) 
, PAIS VARCHAR2(15) 
, ENERGIA_MAX NUMBER(20, 2) NOT NULL 
, ULTIMA_INSPECCION DATE 
, TIPO_CENTRAL VARCHAR2(1) NOT NULL 
, PROPIEDAD1 NUMBER(10, 0) 
, PROPIEDAD2 NUMBER(10, 0) 
, CONSTRAINT CENTRAL_PRODUCCION_PK PRIMARY KEY 
  (
    COD_CENTRAL 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla CLIENTE
----------------------------------------------------------------
/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			CLIENTE
	
	Funcionalidad:				Almacenar los datos principales de los clientes

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE TABLE CLIENTE 
(
  DNI_NIF VARCHAR2(12) NOT NULL 
, DIRECCION VARCHAR2(40) 
, LOCALIDAD VARCHAR2(15) 
, PAIS VARCHAR2(15) 
, CORREO VARCHAR2(30) 
, TELEFONO VARCHAR2(9) 
, DENOMINACION VARCHAR2(50) NOT NULL 
, CONTACTO VARCHAR2(20) 
, CONSTRAINT CLIENTE_PK PRIMARY KEY 
  (
    DNI_NIF 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla CONTADOR
----------------------------------------------------------------
/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			CONTADOR
	
	Funcionalidad:				Almacenar los datos principales de los contadores

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE TABLE CONTADOR 
(
  COD_CONTADOR NUMBER(12, 0) NOT NULL 
, DIRECCION VARCHAR2(40) 
, LOCALIDAD VARCHAR2(15) 
, PAIS VARCHAR2(15) 
, ACUMULADOR NUMBER(38, 2) 
, MODELO VARCHAR2(20) NOT NULL 
, CONSTRAINT CONTADOR_PK PRIMARY KEY 
  (
    COD_CONTADOR 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla CONTADOR_CENTRAL
----------------------------------------------------------------
/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			CONTADOR_CENTRAL
	
	Funcionalidad:				Relaciona las entidades CENTRALES DE DISTRIBUCION y CONTADORES
	
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE CONTADOR_CENTRAL 
(
  COD_CONTADOR NUMBER(12, 0) NOT NULL 
, COD_CENTRAL NUMBER(12, 0) NOT NULL 
, CONSTRAINT CONTADOR_CENTRAL_PK PRIMARY KEY 
  (
    COD_CONTADOR 
  , COD_CENTRAL 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla CONTRATO
----------------------------------------------------------------
/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			CONTRATO
	
	Funcionalidad:				Relaciona las entidades CLIENTES y CONTADORES.

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE TABLE CONTRATO 
(
  COD_CONTRATO NUMBER(12, 0) NOT NULL 
, DNI_NIF VARCHAR2(12) NOT NULL 
, COD_CONTADOR NUMBER(12, 0) NOT NULL 
, FECHA_ALTA DATE NOT NULL 
, FECHA_BAJA DATE 
, POTENCIA NUMBER(12, 0) NOT NULL 
, CONSTRAINT CONTRATO_PK PRIMARY KEY 
  (
    COD_CONTRATO 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla E1
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			E1
	
	Funcionalidad:				La tabla almacenará los datos de todas las centrales de producción 
								sumando el consumo de cada contador agrupado. 
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE E1 
(
  COD_CONTADOR NUMBER(12, 0) NOT NULL 
, ACUMULADOR NUMBER(12, 2) NOT NULL 
, COD_CENTRAL NUMBER(12, 0) NOT NULL 
);
/
----------------------------------------------------------------
-- Script para crear la tabla E2
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			E2
	
	Funcionalidad:				La tabla almacenará los datos de todas las líneas y años 
								en los que éstas líneas han consumido junto 
								con el valor medio de la energía consumida
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE E2 
(
  VALOR_MEDIO NUMBER(12, 2) NOT NULL 
, COD_LINEA NUMBER(12, 0) NOT NULL 
, ANYO NUMBER(4, 0) NOT NULL 
);
/
----------------------------------------------------------------
-- Script para crear la tabla E3
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			E3
	
	Funcionalidad:				La tabla almacenará el código identificativo de 
								la línea de comunicación que esté mas cargada 
								de todas las existentes de energía que se haya consumido
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE E3 
(
  COD_LINEA NUMBER(12, 0) NOT NULL 
);
/
----------------------------------------------------------------
-- Script para crear la tabla E4
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			E4
	
	Funcionalidad:				La tabla almacenará el porcentaje de las 
								líneas que superan el 50% de la energía consumida para todos los años
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE E4 
(
  PORCENTAJE_LINEA NUMBER(2, 0) NOT NULL 
, ANYO NUMBER(4, 0) NOT NULL 
);
/
----------------------------------------------------------------
-- Script para crear la tabla E5
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			E5
	
	Funcionalidad:				La tabla almacenará el número de centrales de producción 
								que generan menos del 30% de la producción para todos los años. 
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE E5 
(
  NUM_CENTRALES_PRODUCCION NUMBER(4, 0) NOT NULL 
, ANYO NUMBER(4, 0) NOT NULL 
);
/
----------------------------------------------------------------
-- Script para crear la tabla E6
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			E6
	
	Funcionalidad:				La tabla almacenará siempre diez registros que coincidirán 
								con las diez claves identificativas de los contadores 
								que a lo largo de toda la vida del sistema han tenido mas consumo
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE E6 
(
  COD_CONTADOR NUMBER(12, 0) NOT NULL 
);
/
----------------------------------------------------------------
-- Script para crear la tabla E7
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			E7
	
	Funcionalidad:				Listado de los clientes con su consumo medio
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE E7 
(
  DNI_NIF VARCHAR2(12) NOT NULL 
, CONSUMO_MEDIO NUMBER(12, 2) NOT NULL 
);
/
----------------------------------------------------------------
-- Script para crear la tabla HIST_ENERGIA_EMITIDA
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			HIST_ENERGIA_EMITIDA
	
	Funcionalidad:				Almacenar la cantidad de KWh que una central de distribución emite cada mes.
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE HIST_ENERGIA_EMITIDA 
(
  COD_CENTRAL NUMBER(12, 0) NOT NULL 
, FECHA DATE NOT NULL 
, LECTURA NUMBER(12, 2) NOT NULL 
, CONSTRAINT HIST_ENERGIA_EMITIDA_PK PRIMARY KEY 
  (
    COD_CENTRAL 
  , FECHA 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla HIST_ENERGIA_PRODUCIDA
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			HIST_ENERGIA_PRODUCIDA
	
	Funcionalidad:				Almacenar la cantidad de KWh que una central de producción fabrica cada mes.
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE HIST_ENERGIA_PRODUCIDA 
(
  COD_CENTRAL NUMBER(12, 0) NOT NULL 
, FECHA DATE NOT NULL 
, LECTURA NUMBER(12, 2) NOT NULL 
, CONSTRAINT HIST_ENERGIA_PRODUCIDA_PK PRIMARY KEY 
  (
    COD_CENTRAL 
  , FECHA 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla HIST_LECTURA
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			HIST_LECTURA
	
	Funcionalidad:				Tabla que almacena las lecturas de los contadores que se hacen mensualmente
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE HIST_LECTURA 
(
  FECHA DATE NOT NULL 
, COD_CONTADOR NUMBER(12, 0) NOT NULL 
, LECUTRA NUMBER(12, 2) NOT NULL 
, MODO VARCHAR2(1) NOT NULL 
, CONSTRAINT HIST_LECTURA_PK PRIMARY KEY 
  (
    FECHA ,
	COD_CONTADOR
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla LINEA_COMUNICA
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			LINEA_COMUNICA
	
	Funcionalidad:				Relación entre las centrales de producción y las de distribución 
								a través de sus líneas de comunicación
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE LINEA_COMUNICA 
(
  COD_LINEA NUMBER(12, 0) NOT NULL 
, CAPACIDAD_MAX NUMBER(20, 2) NOT NULL 
, COD_CENTRAL NUMBER(12, 0) NOT NULL 
, CONSTRAINT LINEA_COMUNICA_PK PRIMARY KEY 
  (
    COD_LINEA 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla LOG
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			LOG
	
	Funcionalidad:				Mantener un log de la actividad de la BBDD
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE LOG 
(
  FECHA DATE NOT NULL 
, PROCEDIMIENTO VARCHAR2(50) NOT NULL 
, PARAM_ENTRADA VARCHAR2(100) 
, PARAM_SALIDA VARCHAR2(100) 
, USUARIO VARCHAR2(25) NOT NULL 
, CONSTRAINT LOG_PK PRIMARY KEY 
  (
    FECHA 
  , USUARIO 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla MODELO_CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			MODELO_CONTADOR
	
	Funcionalidad:				Almacenar los datos principales de los modelos de contador existentes
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE MODELO_CONTADOR 
(
  MODELO VARCHAR2(20) NOT NULL 
, EMPRESA_FABRICACION VARCHAR2(20) NOT NULL 
, ANYO_FABRICACION NUMBER(4, 0) NOT NULL 
, DENOMINACION VARCHAR2(50) 
, CONSTRAINT MODELO_CONTADOR_PK PRIMARY KEY 
  (
    MODELO 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la tabla TIPO_CENTRAL
----------------------------------------------------------------
/***************************************************************

	Fecha de creación:			06/04/2012

	Usuario de la creación:		UOC
	
	Nombre de la tabla:			TIPO_CENTRAL
	
	Funcionalidad:				Maestro de tipos de central de producción que nos informarán del significado 
								de los atributos “Propiedad1” y “Propiedad2” de las centrales de producción.
								
	MODIFICACIONES POSTERIORES:
					
*******************************************************************************************************/
CREATE TABLE TIPO_CENTRAL 
(
  TIPO_CENTRAL NUMBER(1, 0) NOT NULL 
, DESCRIPCION VARCHAR2(20) NOT NULL 
, PROPIEDAD1 VARCHAR2(20) 
, PROPIEDAD2 VARCHAR2(20) 
, CONSTRAINT TIPO_CENTRAL_PK PRIMARY KEY 
  (
    TIPO_CENTRAL 
  )
  ENABLE 
);
/
----------------------------------------------------------------
-- Script para crear la secuencia de la clave primaria de la tabla CENTRAL_DISTRIBUCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	SEQ_COD_CENTRAL_DIST
	
	Funcionalidad: Creacin de la clave primaria de la tabla CENTRAL_DISTRIBUCION, campo COD_CENTRAL

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE SEQUENCE SEQ_COD_CENTRAL_DIST INCREMENT BY 1 START WITH 1 MAXVALUE 999999999999 MINVALUE 1;
/
----------------------------------------------------------------
-- Script para crear la secuencia de la clave primaria de la tabla CENTRAL_PRODUCCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	SEQ_COD_CENTRAL_PROD
	
	Funcionalidad: Creacin de la clave primaria de la tabla CENTRAL_PRODUCCION, campo COD_CENTRAL

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE SEQUENCE SEQ_COD_CENTRAL_PROD INCREMENT BY 1 START WITH 1 MAXVALUE 999999999999 MINVALUE 1;
/
----------------------------------------------------------------
-- Script para crear la secuencia de la clave primaria de la tabla CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	SEQ_COD_CONTADOR
	
	Funcionalidad: Creacin de la clave primaria de la tabla CONTADOR, campo COD_CONTADOR

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE SEQUENCE SEQ_COD_CONTADOR INCREMENT BY 1 START WITH 1 MAXVALUE 999999999999 MINVALUE 1;
/
----------------------------------------------------------------
-- Script para crear la secuencia de la clave primaria de la tabla CONTRATO
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	SEQ_COD_CONTRATO
	
	Funcionalidad: Creacin de la clave primaria de la tabla CONTRATO, campo COD_CONTRATO

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE SEQUENCE SEQ_COD_CONTRATO INCREMENT BY 1 START WITH 1 MAXVALUE 999999999999 MINVALUE 1;
/
----------------------------------------------------------------
-- Script para crear la secuencia de la clave primaria de la tabla LINEA_COMUNICA
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	SEQ_COD_LINEA
	
	Funcionalidad: Creacin de la clave primaria de la tabla LINEA_COMUNICA, campo COD_LINEA

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE SEQUENCE SEQ_COD_LINEA INCREMENT BY 1 START WITH 1 MAXVALUE 999999999999 MINVALUE 1;
/
----------------------------------------------------------------
-- Script para crear la secuencia de la clave primaria de la tabla TIPO_CENTRAL
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	SEQ_TIPO_CENTRAL
	
	Funcionalidad: Creacin de la clave primaria de la tabla TIPO_CENTRAL, campo TIPO_CENTRAL

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/
CREATE SEQUENCE SEQ_TIPO_CENTRAL INCREMENT BY 1 START WITH 1 MAXVALUE 9 MINVALUE 1;
/

