
----------------------------------------------------------------
-- Script para insertar en la tabla LOG
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_log_insert
	
	Funcionalidad:			Inserta un registro en la tabla LOG

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					PROCEDIMIENTO   STRING        	'P_CONTADOR_INSERT'
					PARAM_ENTRADA	STRING			'PZA.ESPANA|MADRID|ESPANA|0|1'
					PARAM_SALIDA	STRING			'OK'

	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp		    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: numero de error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- Error desconocido

	Ejemplo de uso:			p_log_insert('P_CONTADOR_INSERT','PZA.ESPANA|MADRID|ESPANA|0|1','OK', RSP);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

CREATE OR REPLACE PROCEDURE P_LOG_INSERT 
(
  PROCEDIMIENTO IN VARCHAR2  
, PARAM_ENTRADA IN VARCHAR2  
, PARAM_SALIDA IN VARCHAR2  
, RSP OUT VARCHAR2  
) AS 

  PROCEDIMIENTO2 VARCHAR2(25);
  PARAM_SALIDA2 VARCHAR2(50);
  PARAM_ENTRADA2 VARCHAR2(50);
BEGIN
  
    -- Realizo la insercin del registro del log de los datos que me pasa por parmetros
    -- El primer campo es la fecha que la saca de sysdate
    -- El ltimo campo es el usuario que realiza la llamada al procedure, como en nuestro caso solo hay
    -- uno, se incluye por defecto
     
	-- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	PROCEDIMIENTO2 	:= UPPER(TRIM(PROCEDIMIENTO));	
	PARAM_ENTRADA2 	:= UPPER(TRIM(PARAM_ENTRADA));	
	PARAM_SALIDA2 	:= UPPER(TRIM(PARAM_SALIDA));		
	
    INSERT INTO LOG 
    (FECHA,
     PROCEDIMIENTO     ,
     PARAM_ENTRADA     ,
     PARAM_SALIDA      ,
     USUARIO)
    values 
    (SYSDATE,
     PROCEDIMIENTO2,
     PARAM_ENTRADA2,
     PARAM_SALIDA2,
     'UOC');
    
    RSP:= 'OK'; 
     
  
EXCEPTION

  WHEN DUP_VAL_ON_INDEX THEN 
    dbms_output.put_line('La clave est duplicada');
    RSP:= 'ERROR:1';
  
  WHEN ROWTYPE_MISMATCH THEN
    dbms_output.put_line('Tipo de dato no esperado');
    RSP:= 'ERROR:2';
  
  WHEN OTHERS THEN
    dbms_output.put_line('Error no esperado');
    RSP:= 'ERROR:3';

  
END P_LOG_INSERT;
/
----------------------------------------------------------------
-- Script para insertar en la tabla TIPO_CENTRAL
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_tipo_central_insert
	
	Funcionalidad:			Inserta un registro en la tabla TIPO_CENTRAL

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DESCRIPCION	    STRING        	'EOLICA'
					PROPIEDAD1		STRING			'Nmero de molinos'
					PROPIEDAD2		STRING			''

	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido

	Ejemplo de uso:			p_tipo_central_insert('EOLICA','Nmero de molinos','',RSP1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_TIPO_CENTRAL_INSERT 
(
  DESCRIPCION IN VARCHAR2  
, PROPIEDAD1 IN VARCHAR2  
, PROPIEDAD2 IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DESCRIPCION2 VARCHAR2(20);
  PROPIEDAD12 VARCHAR2(20);
  PROPIEDAD22 VARCHAR2(20);
  
BEGIN
  
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (DESCRIPCION IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DESCRIPCION2 	:= UPPER(TRIM(DESCRIPCION));	
	PROPIEDAD12 	:= UPPER(TRIM(PROPIEDAD1));	
	PROPIEDAD22 	:= UPPER(TRIM(PROPIEDAD2));	
  
  -- Realizamos el insert
  INSERT INTO TIPO_CENTRAL 
  (TIPO_CENTRAL,
   DESCRIPCION      ,
   PROPIEDAD1     ,
   PROPIEDAD2)
  values 
  (SEQ_TIPO_CENTRAL.NextVal,
   DESCRIPCION2,
   PROPIEDAD12,
   PROPIEDAD22);
  
  IF (PROPIEDAD12 IS NULL)  THEN
    PROPIEDAD12:=' ';
  END IF;
  
  IF (PROPIEDAD22 IS NULL)  THEN
    PROPIEDAD22:=' ';
  END IF;
  
  rsp_log := 'OK';
  param_entrada := DESCRIPCION2 || '|' || PROPIEDAD12 || '|' || PROPIEDAD22 || '|';
  P_LOG_INSERT('P_TIPO_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
  
  -- Control de excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := DESCRIPCION2 || '|' || PROPIEDAD12 || '|' || PROPIEDAD22 || '|';
      P_LOG_INSERT('P_TIPO_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	  rsp := 'ERROR:2';
      param_entrada := DESCRIPCION2 || '|' || PROPIEDAD12 || '|' || PROPIEDAD22 || '|';
      P_LOG_INSERT('P_TIPO_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	  rsp := 'ERROR:3';
      param_entrada := DESCRIPCION2 || '|' || PROPIEDAD12 || '|' || PROPIEDAD22 || '|';
      P_LOG_INSERT('P_TIPO_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
        
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	  rsp := 'ERROR:4';
      param_entrada := DESCRIPCION2 || '|' || PROPIEDAD12 || '|' || PROPIEDAD22 || '|';
      P_LOG_INSERT('P_TIPO_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
   
END P_TIPO_CENTRAL_INSERT;
/
----------------------------------------------------------------
-- Script para insertar en la tabla CENTRAL_PRODUCCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_central_produccion_insert
	
	Funcionalidad:			Inserta un registro en la tabla CENTRAL_PRODUCCION 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DIRECCION	    STRING        	'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					ENERGIA_MAX		NUMBER(20,2)	100
					ULTIMA_INSPECCION	DATE		01/02/2012
					TIPO_CENTRAL	NUMBER(1)		1	
					PROPIEDAD1		NUMBER(10)		0	
					PROPIEDAD2		NUMBER(10)		0

	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido
					5-- No encontrado el tipo de central

	Ejemplo de uso:			p_central_produccion_insert('Pza.Espaa','Madrid','Espaa', 100, 01/02/2012, 1, 15, 0, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CENTRAL_PRODUCCION_INSERT 
(
  DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, ENERGIA_MAX IN NUMBER  
, ULTIMA_INSPECCION IN DATE  
, TIPO_CENTRAL IN NUMBER 
, PROPIEDAD1 IN NUMBER  
, PROPIEDAD2 IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  tipo_central2 NUMBER;
  
  DIRECCION2 VARCHAR2(40);
  LOCALIDAD2 VARCHAR2(15);
  PAIS2 VARCHAR2(15);
  
  PROPIEDAD22 NUMBER;
  PROPIEDAD12 NUMBER;
  ENERGIA_MAX2 NUMBER;
  ULTIMA_INSPECCION2 DATE;
  
  TC NUMBER;
  
BEGIN
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (ENERGIA_MAX IS NULL) OR (TIPO_CENTRAL IS NULL ) THEN
    RAISE campos_nulos;
  END IF;
  
  
  TC := TIPO_CENTRAL;
  
  -- Comprobamos que el tipo central existe en suu tabla 
  SELECT  TIPO_CENTRAL
  INTO    tipo_central2 
  FROM    TIPO_CENTRAL
  WHERE   TIPO_CENTRAL = TC;
  
  
   -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
  ENERGIA_MAX2 := ENERGIA_MAX;
  PROPIEDAD12 := PROPIEDAD1;
  PROPIEDAD22 := PROPIEDAD2;
  ULTIMA_INSPECCION2 := ULTIMA_INSPECCION;
  DIRECCION2 	:= UPPER(TRIM(DIRECCION));	  
  PAIS2 	:= UPPER(TRIM(PAIS));	  
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
  
   -- Realizamos el insert
  INSERT INTO CENTRAL_PRODUCCION 
  (COD_CENTRAL,
   DIRECCION      ,
   LOCALIDAD     ,
   PAIS ,
   ENERGIA_MAX,
   ULTIMA_INSPECCION,
   TIPO_CENTRAL,
   PROPIEDAD1,
   PROPIEDAD2)
  values 
  (SEQ_COD_CENTRAL_PROD.NextVal,
   DIRECCION2,
   LOCALIDAD2     ,
   PAIS2 ,
   ENERGIA_MAX2,
   ULTIMA_INSPECCION2,
   TC,
   PROPIEDAD12,
   PROPIEDAD22);
  
   rsp_log := 'OK';
   param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || TIPO_CENTRAL || '|'|| PROPIEDAD1 || '|'|| PROPIEDAD2 || '|';
  P_LOG_INSERT('P_CENTRAL_PRODUCCION_INSERT', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Excepciones
  EXCEPTION
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := ENERGIA_MAX || '|' || TIPO_CENTRAL || '|' || PROPIEDAD2 || '|';
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:2';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || TIPO_CENTRAL || '|'|| PROPIEDAD1 || '|'|| PROPIEDAD2 || '|';
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:3';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || TIPO_CENTRAL || '|'|| PROPIEDAD1 || '|'|| PROPIEDAD2 || '|';
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el tipo de central';
	    rsp := 'ERROR:5';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || TIPO_CENTRAL || '|'|| PROPIEDAD1 || '|'|| PROPIEDAD2 || '|';
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || TIPO_CENTRAL || '|'|| PROPIEDAD1 || '|'|| PROPIEDAD2 || '|';
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_CENTRAL_PRODUCCION_INSERT;
/

----------------------------------------------------------------
-- Script para insertar en la tabla CLIENTE
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_cliente_insert
	
	Funcionalidad:			Inserta un registro en la tabla CLIENTE 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DNI_NIF		    STRING        	'12345678X'
					DIRECCION		STRING			'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					CORREO			STRING			'prueba@gmail.com'
					TELEFONO		STRING			'976666666'
					DENOMINACION	STRING			'FEDERICO GONZALEZ'	
					CONTACTO		STRING			'FEDERICO'	
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido
				
	Ejemplo de uso:			p_cliente_insert('12345678X', 'Pza.Espaa','Madrid','Espaa','prueba@gmail.com', '976666666','FEDERICO GONZALEZ', 'FEDERICO', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_CLIENTE_INSERT 
(
  DNI_NIF IN VARCHAR2  
, DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, CORREO IN VARCHAR2  
, TELEFONO IN VARCHAR2  
, DENOMINACION IN VARCHAR2  
, CONTACTO IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DNI_NIF2 VARCHAR2(12);
  DIRECCION2 VARCHAR2(40);  
  LOCALIDAD2 VARCHAR2(15);  
  PAIS2 VARCHAR2(15);
  CORREO2 VARCHAR2(30);
  TELEFONO2 VARCHAR2(9);
  DENOMINACION2 VARCHAR2(50);
  CONTACTO2 VARCHAR2(50);
  
BEGIN
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (DNI_NIF IS NULL) OR (DENOMINACION IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
   -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DNI_NIF2 	:= UPPER(TRIM(DNI_NIF));	
	DIRECCION2 	:= UPPER(TRIM(DIRECCION));	
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
 	PAIS2 	:= UPPER(TRIM(PAIS));	
	CORREO2 	:= UPPER(TRIM(CORREO));	
	TELEFONO2 	:= UPPER(TRIM(TELEFONO));	
  DENOMINACION2 	:= UPPER(TRIM(DENOMINACION));	
	CONTACTO2 	:= UPPER(TRIM(CONTACTO));	
  
   -- Realizamos el insert
  INSERT INTO CLIENTE 
  (DNI_NIF,
   DIRECCION,
   LOCALIDAD,
   PAIS,
   CORREO,
   TELEFONO,
   DENOMINACION,
   CONTACTO)
  values 
  (DNI_NIF2,
   DIRECCION2,
   LOCALIDAD2,
   PAIS2,
   CORREO2,
   TELEFONO2,
   DENOMINACION2,
   CONTACTO2);
  
  rsp_log := 'OK';
  param_entrada := DNI_NIF2 || '|' || DIRECCION2 || '|' || LOCALIDAD2 || '|'|| PAIS2 || '|' || CORREO2 || '|'|| TELEFONO2 || '|' || DENOMINACION2 || '|'|| CONTACTO2 || '|' ;
  P_LOG_INSERT('P_CLIENTE_INSERT', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Control de excepciones
  EXCEPTION
  
 
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := DNI_NIF || '|' || DENOMINACION || '|' ;
      P_LOG_INSERT('P_CLIENTE_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:2';
      param_entrada := DNI_NIF2 || '|' || DIRECCION2 || '|' || LOCALIDAD2 || '|'|| PAIS2 || '|' || CORREO2 || '|'|| TELEFONO2 || '|' || DENOMINACION2 || '|'|| CONTACTO2 || '|' ;
      P_LOG_INSERT('P_CLIENTE_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:3';
      param_entrada := DNI_NIF2 || '|' || DIRECCION2 || '|' || LOCALIDAD2 || '|'|| PAIS2 || '|' || CORREO2 || '|'|| TELEFONO2 || '|' || DENOMINACION2 || '|'|| CONTACTO2 || '|' ;
      P_LOG_INSERT('P_CLIENTE_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT; 
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := DNI_NIF2 || '|' || DIRECCION2 || '|' || LOCALIDAD2 || '|'|| PAIS2 || '|' || CORREO2 || '|'|| TELEFONO2 || '|' || DENOMINACION2 || '|'|| CONTACTO2 || '|' ;
      P_LOG_INSERT('P_CLIENTE_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
  
  
END P_CLIENTE_INSERT;
/
----------------------------------------------------------------
-- Script para insertar en la tabla CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contador_insert
	
	Funcionalidad:			Inserta un registro en la tabla CONTADOR 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DIRECCION		STRING			'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					ACUMULADOR		NUMBER			0
					MODELO			STRING			'R6ym'					
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido
					5-- Modelo de contador no encontrado
				
	Ejemplo de uso:			p_contador_insert('Pza.Espaa','Madrid','Espaa',0, 'R6ym', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_CONTADOR_INSERT 
(
  DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, ACUMULADOR IN NUMBER  
, MODELO IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 
 
  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  DIRECCION2 VARCHAR2(40);  
  LOCALIDAD2 VARCHAR2(15);  
  PAIS2 VARCHAR2(15);
  MODELO2 VARCHAR2(20);

BEGIN
  
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (MODELO IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DIRECCION2 	:= UPPER(TRIM(DIRECCION));	
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
 	PAIS2 	    := UPPER(TRIM(PAIS));	
  MODELO2     := UPPER(TRIM(MODELO));	
  
  -- Comprobamos que existe el modelo en la tabla de modelos de contador
  SELECT  MODELO
  INTO    MODELO2 
  FROM    MODELO_CONTADOR
  WHERE   MODELO = MODELO2;
  
  -- Realizamos el insert
   INSERT INTO CONTADOR 
  (COD_CONTADOR,
   DIRECCION      ,
   LOCALIDAD     ,
   PAIS ,
   ACUMULADOR,
   MODELO)
  values 
  (SEQ_COD_CONTADOR.NextVal,
   DIRECCION2,
   LOCALIDAD2     ,
   PAIS2 ,
   ACUMULADOR,
   MODELO);
  
  rsp_log := 'OK';
  param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
  P_LOG_INSERT('P_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Excepciones
  EXCEPTION
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := MODELO|| '|';
      P_LOG_INSERT('P_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:2';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:3';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el modelo de contador ';
	    rsp := 'ERROR:5';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
END P_CONTADOR_INSERT;
/

----------------------------------------------------------------
-- Script para insertar en la tabla CONTADOR_CENTRAL
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contador_central_insert
	
	Funcionalidad:			Inserta un registro en la tabla CONTADOR_CENTRAL 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CONTADOR	STRING			25
					COD_CENTRAL		STRING			1				
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- Clave foranea no encontrada 
					4-- Error desconocido				
				
	Ejemplo de uso:			p_contador_central_insert(25,1, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CONTADOR_CENTRAL_INSERT 
(
  COD_CONTADOR IN NUMBER  
, COD_CENTRAL IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  
  COD_CONTADOR2 NUMBER;
  COD_CENTRAL2 NUMBER;
  
  COD NUMBER;
  CENTRAL NUMBER;
BEGIN
  
  COD := COD_CONTADOR;
  CENTRAL := COD_CENTRAL;
  
   -- Comprobamos que el contador existe en la tabla de contadores
  SELECT  COD_CONTADOR
  INTO    COD_CONTADOR2 
  FROM    CONTADOR
  WHERE   COD_CONTADOR = COD;
  
  -- Comprobamos que la central existe en centrales de distribucion
  SELECT  COD_CENTRAL
  INTO    COD_CENTRAL2 
  FROM    CENTRAL_DISTRIBUCION 
  WHERE   COD_CENTRAL = CENTRAL;
  
  -- Realizamos el insert
  INSERT INTO CONTADOR_CENTRAL 
  (COD_CONTADOR,
   COD_CENTRAL)
  values 
  (COD,
   CENTRAL);
   
    rsp_log := 'OK';
 param_entrada := COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
  P_LOG_INSERT('P_CONTADOR_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
 
   
  -- Excepciones
  EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CONTADOR_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CONTADOR_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado clave fornea';
	    rsp := 'ERROR:3';
      param_entrada := COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CONTADOR_CENTRAL_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
   
  
END P_CONTADOR_CENTRAL_INSERT;
/
----------------------------------------------------------------
-- Script para insertar en la tabla CONTRATO
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contrato_insert
	
	Funcionalidad:			Inserta un registro en la tabla CONTRATO 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DNI_NIF			STRING			'12345678X'
					COD_CONTADOR	NUMBER			1				
					FECHA_ALTA		DATE			'01/10/2009'
					FECHA_BAJA		DATE			''
					POTENCIA		NUMBER			12
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- Clave foranea no encontrada 
					4-- Error desconocido	
				    5-- Campos nulos
				
	Ejemplo de uso:			p_contrato_insert('12345678X', 1, '01/10/2009','',12, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CONTRATO_INSERT 
(
  DNI_NIF IN VARCHAR2  
, COD_CONTADOR IN NUMBER  
, FECHA_ALTA IN DATE  
, FECHA_BAJA IN DATE  
, POTENCIA IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DNI_NIF2 VARCHAR2(12);
  DNI_NIF3 VARCHAR2(12);
  COD_CONTADOR2 NUMBER;
  CONTADOR NUMBER;

  ALTA DATE;
  BAJA DATE;
  POTENCIA2 NUMBER;

BEGIN

   -- Comprobacion de los atributos que no pueden ser nulos
  IF (DNI_NIF IS NULL) OR (COD_CONTADOR IS NULL) OR (POTENCIA IS NULL) OR (FECHA_ALTA IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  CONTADOR := COD_CONTADOR;
  
   -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DNI_NIF2 	:= UPPER(TRIM(DNI_NIF));	
	ALTA:= FECHA_ALTA;
  BAJA:= FECHA_BAJA;
  POTENCIA2 := POTENCIA;
  
   -- Comprobamos que el contador existe en la tabla de contadores
  SELECT  COD_CONTADOR
  INTO    COD_CONTADOR2 
  FROM    CONTADOR
  WHERE   COD_CONTADOR = CONTADOR;
  
   -- Comprobamos que el cliente existe en la tabla de clientes
  SELECT  DNI_NIF
  INTO    DNI_NIF3 
  FROM    CLIENTE
  WHERE   DNI_NIF = DNI_NIF2;
  
  -- Realizamos el insert
  INSERT INTO CONTRATO 
  (COD_CONTRATO,
   DNI_NIF,
   COD_CONTADOR, 
   FECHA_ALTA,
   FECHA_BAJA,
   POTENCIA)
  values 
  (SEQ_COD_CONTRATO.NEXTVAL,
   DNI_NIF2,
   CONTADOR,
   ALTA,
   BAJA,
   POTENCIA2);
    
  rsp_log := 'OK';
  param_entrada := DNI_NIF || '|' || COD_CONTADOR || '|' || FECHA_ALTA || '|'|| FECHA_BAJA || '|'|| POTENCIA || '|';
  P_LOG_INSERT('P_CONTRATO_INSERT', param_entrada, rsp_log, rsp_log_out);
  
   -- Excepciones
  EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := DNI_NIF || '|' || COD_CONTADOR || '|' || FECHA_ALTA || '|'|| FECHA_BAJA || '|'|| POTENCIA || '|';
      P_LOG_INSERT('P_CONTRATO_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
       param_entrada := DNI_NIF || '|' || COD_CONTADOR || '|' || FECHA_ALTA || '|'|| FECHA_BAJA || '|'|| POTENCIA || '|';
      P_LOG_INSERT('P_CONTRATO_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado clave fornea';
	    rsp := 'ERROR:3';
       param_entrada := DNI_NIF || '|' || COD_CONTADOR || '|' || FECHA_ALTA || '|'|| FECHA_BAJA || '|'|| POTENCIA || '|';
      P_LOG_INSERT('P_CONTRATO_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := DNI_NIF || '|' || COD_CONTADOR || '|' || FECHA_ALTA || '|'|| FECHA_BAJA || '|'|| POTENCIA || '|';
      P_LOG_INSERT('P_CONTRATO_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
       param_entrada := DNI_NIF || '|' || COD_CONTADOR || '|' || FECHA_ALTA || '|'|| FECHA_BAJA || '|'|| POTENCIA || '|';
      P_LOG_INSERT('P_CONTRATO_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
   
  
  
END P_CONTRATO_INSERT;
/

----------------------------------------------------------------
-- Script para insertar en la tabla MODELO_CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_modelo_contador_insert
	
	Funcionalidad:			Inserta un registro en la tabla MODELO_CONTADOR 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					MODELO			STRING			'R7g86'
					EMPRESA_FABRICACION	STRING		'Comex SA'
					ANYO_FABRICACION	NUMBER		2009
					DENOMINACION	STRING			'Estandar 10P'
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					4-- Error desconocido	
				    3-- Campos nulos
				
	Ejemplo de uso:			p_modelo_contador_insert('R7g86', 'Comex SA', 2009,'Estandar 10P', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_MODELO_CONTADOR_INSERT 
(
  MODELO IN VARCHAR2  
, EMPRESA_FABRICACION IN VARCHAR2  
, ANYO_FABRICACION IN NUMBER  
, DENOMINACION IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  MODELO2 VARCHAR2(20);
  EMPRESA_FABRICACION2 VARCHAR2(20);  
  DENOMINACION2 VARCHAR2(50);  
  
BEGIN
  
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (MODELO IS NULL) OR (EMPRESA_FABRICACION IS NULL) OR (ANYO_FABRICACION IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
   -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	MODELO2 	:= UPPER(TRIM(MODELO));	
	EMPRESA_FABRICACION2 	:= UPPER(TRIM(EMPRESA_FABRICACION));	
	DENOMINACION2 	:= UPPER(TRIM(DENOMINACION));	

  -- Realizamos el insert 
   INSERT INTO MODELO_CONTADOR 
  (MODELO,
   EMPRESA_FABRICACION,
   ANYO_FABRICACION, 
   DENOMINACION)
  values 
  (MODELO2,
   EMPRESA_FABRICACION2,
   ANYO_FABRICACION,
   DENOMINACION2);
   
    rsp_log := 'OK';
  param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|'|| DENOMINACION || '|';
  P_LOG_INSERT('P_MODELO_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
 
   
      -- Excepciones
  EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|'|| DENOMINACION || '|';
      P_LOG_INSERT('P_MODELO_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
       param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|'|| DENOMINACION || '|';
      P_LOG_INSERT('P_MODELO_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT; 
      
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:3';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|'|| DENOMINACION || '|';
      P_LOG_INSERT('P_CONTRATO_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|'|| DENOMINACION || '|';
      P_LOG_INSERT('P_MODELO_CONTADOR_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_MODELO_CONTADOR_INSERT;
/
----------------------------------------------------------------
-- Script para insertar en la tabla HIST_ENERGIA_EMITIDA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_energia_emitida_insert
	
	Funcionalidad:			Inserta un registro en la tabla HIST_ENERGIA_EMITIDA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CENTRAL		NUMBER			12
					FECHA			DATE			'12/02/2012'
					LECTURA			NUMBER			257
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido	
				    1-- Campos nulos
				
	Ejemplo de uso:			p_hist_energia_emitida_insert(12, '12/02/2012', 257, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_HIST_ENERGIA_EMITIDA_INSERT 
(
  COD_CENTRAL IN NUMBER  
, FECHA IN DATE  
, LECTURA IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  COD_CENTRAL2 NUMBER;
  CENTRAL NUMBER;
  
  FECHA2 DATE;
  LECTURA2 NUMBER;

BEGIN
  
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (LECTURA IS NULL) OR (COD_CENTRAL IS NULL) OR (FECHA IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  CENTRAL := COD_CENTRAL;
  FECHA2 := FECHA;
  LECTURA2 := LECTURA;
  
  -- Comprobamos que el cdigo de central de distribucion existe en central_distribucion
  SELECT  COD_CENTRAL
  INTO    COD_CENTRAL2  
  FROM    CENTRAL_DISTRIBUCION
  WHERE   COD_CENTRAL = CENTRAL;
  
   -- Realizamos el insert
  INSERT INTO HIST_ENERGIA_EMITIDA 
  (COD_CENTRAL,
   FECHA,
   LECTURA)
  values 
  (CENTRAL,
   FECHA2,
   LECTURA2);
 
  rsp_log := 'OK';
  param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
  P_LOG_INSERT('P_HIST_ENERGIA_E_I', param_entrada, rsp_log, rsp_log_out);
  
  
   -- Control de excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_ENERGIA_E_I', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	  rsp := 'ERROR:2';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_ENERGIA_E_I', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	  rsp := 'ERROR:3';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_ENERGIA_E_I', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
        
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_ENERGIA_E_I', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
  
  
END P_HIST_ENERGIA_EMITIDA_INSERT;
/

----------------------------------------------------------------
-- Script para insertar en la tabla HIST_ENERGIA_PRODUCIDA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_energia_prod_insert
	
	Funcionalidad:			Inserta un registro en la tabla HIST_ENERGIA_PRODUCIDA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CENTRAL		NUMBER			12
					FECHA			DATE			'12/02/2012'
					LECTURA			NUMBER			257
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido	
				    1-- Campos nulos
				
	Ejemplo de uso:			p_hist_energia_prod_insert(12, '12/02/2012', 257, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_HIST_ENERGIA_PROD_INSERT 
(
  COD_CENTRAL IN NUMBER  
, FECHA IN DATE  
, LECTURA IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  COD_CENTRAL2 NUMBER;
  CENTRAL NUMBER;
  FECHA2 DATE;
  LECTURA2 NUMBER;

BEGIN
  
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (LECTURA IS NULL) OR (COD_CENTRAL IS NULL) OR (FECHA IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  CENTRAL:= COD_CENTRAL;
  FECHA2:= FECHA;
  LECTURA2 := LECTURA;
  
  -- Comprobamos que el cdigo de central de distribucion existe en central_distribucion
  SELECT  COD_CENTRAL
  INTO    COD_CENTRAL2  
  FROM    CENTRAL_PRODUCCION
  WHERE   COD_CENTRAL = CENTRAL;
  
   -- Realizamos el insert
  INSERT INTO HIST_ENERGIA_PRODUCIDA 
  (COD_CENTRAL,
   FECHA,
   LECTURA)
  values 
  (CENTRAL,
   FECHA2,
   LECTURA2);
  
   rsp_log := 'OK';
   param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
  P_LOG_INSERT('P_HIST_E_P_INSERT', param_entrada, rsp_log, rsp_log_out);
  
 
  
   -- Control de excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_E_P_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	  rsp := 'ERROR:2';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_E_P_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	  rsp := 'ERROR:3';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_E_P_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
        
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|';
      P_LOG_INSERT('P_HIST_E_P_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
  
  
END P_HIST_ENERGIA_PROD_INSERT;
/

----------------------------------------------------------------
-- Script para insertar en la tabla HIST_LECTURA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_lectura_insert
	
	Funcionalidad:			Inserta un registro en la tabla HIST_LECTURA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CONTADO		NUMBER			12
					FECHA			DATE			'12/02/2012'
					LECTURA			NUMBER			257
					MODO			STRING			'P'
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido	
				    1-- Campos nulos
					6-- Modo de lectura no controlado
				
	Ejemplo de uso:			p_hist_lectura_insert(12, '12/02/2012', 257, 'P', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_HIST_LECTURA_INSERT 
(
  COD_CONT IN NUMBER  
, FECHA IN DATE  
, LECTURA IN NUMBER  
, MODO IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  modomal EXCEPTION;

  COD_CONTADOR2 NUMBER;
  MODO2 VARCHAR(1);

BEGIN

   -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CONT IS NULL) OR (LECTURA IS NULL) OR (FECHA IS NULL) OR (MODO IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
    -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	MODO2 	:= UPPER(TRIM(MODO));	
  
  IF (MODO2<>'P') AND (MODO2<>'T') THEN
    RAISE modomal;
  END IF;
  
  -- Comprobamos que el exite el contador en la tabla CONTADOR
  SELECT  COD_CONTADOR 
  INTO    COD_CONTADOR2  
  FROM    CONTADOR 
  WHERE   COD_CONTADOR = COD_CONT;
  
   -- Realizamos el insert
  INSERT INTO HIST_LECTURA 
  (COD_CONTADOR,
   FECHA,
   LECUTRA,
   MODO)
  values 
  (COD_CONT,
   FECHA,
   LECTURA,
   MODO2);
 
  UPDATE CONTADOR
  SET ACUMULADOR = ACUMULADOR + LECTURA 
  WHERE COD_CONTADOR = COD_CONT;
 
  rsp_log := 'OK';
  param_entrada := COD_CONT || '|' || FECHA || '|' || LECTURA || '|'|| MODO || '|';
  P_LOG_INSERT('P_HIST_LECTURA_INSERT', param_entrada, rsp_log, rsp_log_out);
 
    -- Control de excepciones
  EXCEPTION
  
   WHEN modomal THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: El modo no est correcto';
      rsp := 'ERROR:6';
      param_entrada := COD_CONT || '|' || FECHA || '|' || LECTURA || '|'|| MODO || '|';
      P_LOG_INSERT('P_HIST_LECTURA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := COD_CONT || '|' || FECHA || '|' || LECTURA || '|'|| MODO || '|';
      P_LOG_INSERT('P_HIST_LECTURA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:2';
      param_entrada := COD_CONT || '|' || FECHA || '|' || LECTURA || '|'|| MODO || '|';
      P_LOG_INSERT('P_HIST_LECTURA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:3';
      param_entrada := COD_CONT || '|' || FECHA || '|' || LECTURA || '|'|| MODO || '|';
      P_LOG_INSERT('P_HIST_LECTURA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
        
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CONT || '|' || FECHA || '|' || LECTURA || '|'|| MODO || '|';
      P_LOG_INSERT('P_HIST_LECTURA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
 
  
END P_HIST_LECTURA_INSERT;
/
----------------------------------------------------------------
-- Script para insertar en la tabla LINEA_COMUNICA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_linea_comunica_insert
	
	Funcionalidad:			Inserta un registro en la tabla LINEA_COMUNICA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CENTRAL		NUMBER			587
					CAPACIDAD_MAX	NUMBER			895000
															
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- Clave foranea no encontada
					4-- Error desconocido	
				    5-- Campos nulos
				
	Ejemplo de uso:			p_linea_comunica_insert(587, 895000, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_LINEA_COMUNICA_INSERT 
(
  COD_CENTRAL IN NUMBER  
, CAPACIDAD_MAX IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  COD_CENTRAL2 NUMBER;
  CD NUMBER;
  CAPACIDAD_MAX2 NUMBER;
BEGIN
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (CAPACIDAD_MAX IS NULL) OR (COD_CENTRAL IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  CD:= COD_CENTRAL; 
  CAPACIDAD_MAX2:= CAPACIDAD_MAX;
  
  -- Comprobamos que la central de produccion existe
  SELECT  COD_CENTRAL
  INTO    COD_CENTRAL2
  FROM    CENTRAL_PRODUCCION 
  WHERE   COD_CENTRAL = CD;
  
  -- Realizamos el insert
  INSERT INTO LINEA_COMUNICA 
  (COD_LINEA,
   CAPACIDAD_MAX,
   COD_CENTRAL)
  values 
  (SEQ_COD_LINEA.NEXTVAL,
   CAPACIDAD_MAX2,
   CD);
  
   rsp_log := 'OK';
  param_entrada := CAPACIDAD_MAX || '|' || COD_CENTRAL || '|' ;
  P_LOG_INSERT('P_LINEA_COMUNICA_INSERT', param_entrada, rsp_log, rsp_log_out);
 
  
     -- Excepciones
  EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := CAPACIDAD_MAX || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := CAPACIDAD_MAX || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado clave fornea';
	    rsp := 'ERROR:3';
      param_entrada := CAPACIDAD_MAX || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := CAPACIDAD_MAX || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := CAPACIDAD_MAX || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
   
  
END P_LINEA_COMUNICA_INSERT;
/
----------------------------------------------------------------
-- Script para actualizar en la tabla TIPO_CENTAL
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			07/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_tipo_central_update
	
	Funcionalidad:				Actualiza un registro en la tabla TIPO_CENTRAL  

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					TIPO_CENTRAL	NUMBER			1
					DESCRIPCION	    STRING        	'EOLICA'
					PROPIEDAD1		STRING			'Nmero de molinos'
					PROPIEDAD2		STRING			''

	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					5-- Campos nulos
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- Tipo_central no encontrado en la tabla tipo_central 

	Ejemplo de uso:			p_tipo_central_update(1, 'EOLICA','Nmero de molinos','',RSP1);
	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_TIPO_CENTRAL_UPDATE 
(
  TIPO_CENTRAL IN NUMBER  
, DESCRIPCION IN VARCHAR2  
, PROPIEDAD1 IN VARCHAR2  
, PROPIEDAD2 IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DESCRIPCION2 VARCHAR2(20);
  PROPIEDAD12 VARCHAR2(20);
  PROPIEDAD22 VARCHAR2(20);
  TIPO_CENTRAL2 NUMBER;
  TC NUMBER;
  
BEGIN
  
  TC := TIPO_CENTRAL;
  
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (DESCRIPCION IS NULL) or (TIPO_CENTRAL IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
   -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DESCRIPCION2 	:= UPPER(TRIM(DESCRIPCION));	
	PROPIEDAD12 	:= UPPER(TRIM(PROPIEDAD1));	
	PROPIEDAD22 	:= UPPER(TRIM(PROPIEDAD2));	
  
  -- Comprobamos que existe ese  registro en la tabla de TIPO_CENTRAL
  SELECT  TIPO_CENTRAL
  INTO    TIPO_CENTRAL2
  FROM    TIPO_CENTRAL
  WHERE   TIPO_CENTRAL = TC;
  
 
  IF (PROPIEDAD12 IS NULL)  THEN
    PROPIEDAD12:=' ';
  END IF;
  
  IF (PROPIEDAD22 IS NULL)  THEN
    PROPIEDAD22:=' ';
  END IF;
  
  --Realizamos el update
  UPDATE  TIPO_CENTRAL
  SET     DESCRIPCION = DESCRIPCION2,
          PROPIEDAD1  = PROPIEDAD12,
          PROPIEDAD2  = PROPIEDAD22 
  WHERE   TIPO_CENTRAL = TC;
  
  rsp_log := 'OK';
  param_entrada := TIPO_CENTRAL || '|' || DESCRIPCION2 || '|' || PROPIEDAD12 || '|' || PROPIEDAD22 || '|' ;
  P_LOG_INSERT('P_TIPO_CENTRAL_UPDATE', param_entrada, rsp_log, rsp_log_out);
  
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := TIPO_CENTRAL || '|' || DESCRIPCION || '|' || PROPIEDAD1 || '|' || PROPIEDAD2 || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := TIPO_CENTRAL || '|' || DESCRIPCION || '|' || PROPIEDAD1 || '|' || PROPIEDAD2 || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el tipo_central.';
	    rsp := 'ERROR:3';
      param_entrada := TIPO_CENTRAL || '|' || DESCRIPCION || '|' || PROPIEDAD1 || '|' || PROPIEDAD2 || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := TIPO_CENTRAL || '|' || DESCRIPCION || '|' || PROPIEDAD1 || '|' || PROPIEDAD2 || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := TIPO_CENTRAL || '|' || DESCRIPCION || '|' || PROPIEDAD1 || '|' || PROPIEDAD2 || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
   
  
END P_TIPO_CENTRAL_UPDATE;
/
----------------------------------------------------------------
-- Script para borrar un registro en la tabla TIPO_CENTAL
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			07/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_tipo_central_delete
	
	Funcionalidad:				Borra un registro en la tabla TIPO_CENTRAL  

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					TIPO_CENTRAL	NUMBER			1
			

	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- Tipo_central se est usando en la tabla CENTRAL_PRODUCCION

	Ejemplo de uso:			p_tipo_central_delete(1,RSP1);
	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_TIPO_CENTRAL_DELETE 
(
  TIPO_CENTRAL IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  existe_cp EXCEPTION;
  
  NUM_CP NUMBER;
  TC NUMBER;
  
BEGIN

  TC:= TIPO_CENTRAL;
  NUM_CP := 0;

   -- Comprobacion de los atributos que no pueden ser nulos
  IF (TIPO_CENTRAL IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  -- Controlamos que esta clave no se utilice en tablas dependientes
  -- TABLA CENTRAL_PRODUCCION
  SELECT  COUNT(COD_CENTRAL)
  INTO    NUM_CP 
  FROM    CENTRAL_PRODUCCION
  WHERE   TIPO_CENTRAL = TC;
  
  IF (NUM_CP>0) THEN
    RAISE existe_cp;
  END IF;
  
  -- Borramos de la tabla
  DELETE FROM TIPO_CENTRAL 
  WHERE TIPO_CENTRAL = TC;
  
  rsp_log := 'OK';
  param_entrada :=  TIPO_CENTRAL || '|' ;
  P_LOG_INSERT('P_TIPO_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
    
  -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  TIPO_CENTRAL || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  WHEN existe_cp THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: El tipo central se est usando en CP';
      rsp := 'ERROR:3';
      param_entrada :=  TIPO_CENTRAL || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  TIPO_CENTRAL || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  TIPO_CENTRAL || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
END P_TIPO_CENTRAL_DELETE;
/
----------------------------------------------------------------
-- Script para actualiza en la tabla MODELO_CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_modelo_contador_update
	
	Funcionalidad:				Actualiza un registro en la tabla MODELO_CONTADOR 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					MODELO			STRING			'R7g86'
					EMPRESA_FABRICACION	STRING		'Comex SA'
					ANYO_FABRICACION	NUMBER		2009
					DENOMINACION	STRING			'Estandar 10P'
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					4-- Error desconocido	
				    5-- Campos nulos
					3-- Modelo no encontado 
				
	Ejemplo de uso:			p_modelo_contador_update('R7g86', 'Comex SA', 2009,'Estandar 10P', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_MODELO_CONTADOR_UPDATE 
(
  MODELO IN VARCHAR2  
, EMPRESA_FABRICACION IN VARCHAR2  
, ANYO_FABRICACION IN NUMBER  
, DENOMINACION IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  MODELO2 VARCHAR2(20);
  MODELO3 VARCHAR2(20);
  EMPRESA_FABRICACION2 VARCHAR2(20);  
  DENOMINACION2 VARCHAR2(50);  

  M VARCHAR2(20);

BEGIN
  
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (MODELO IS NULL) OR (EMPRESA_FABRICACION IS NULL) OR (ANYO_FABRICACION IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	MODELO2 	:= UPPER(TRIM(MODELO));	
	EMPRESA_FABRICACION2 	:= UPPER(TRIM(EMPRESA_FABRICACION));	
	DENOMINACION2 	:= UPPER(TRIM(DENOMINACION));	
  
  M:=MODELO2;
  
  -- Comprobamos que existe en la tabla MODELO_CONTADOR
  SELECT  MODELO
  INTO    MODELO3
  FROM    MODELO_CONTADOR
  WHERE   MODELO = M;
  
   --Realizamos el update
  UPDATE  MODELO_CONTADOR
  SET     EMPRESA_FABRICACION = EMPRESA_FABRICACION2,
          ANYO_FABRICACION  = ANYO_FABRICACION,
          DENOMINACION  = DENOMINACION2 
  WHERE   MODELO = M;
  
   rsp_log := 'OK';
  param_entrada :=  M || '|' ;
  P_LOG_INSERT('P_MODELO_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|' || DENOMINACION || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|' || DENOMINACION || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el modelo.';
	    rsp := 'ERROR:3';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|' || DENOMINACION || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|' || DENOMINACION || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := MODELO || '|' || EMPRESA_FABRICACION || '|' || ANYO_FABRICACION || '|' || DENOMINACION || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_MODELO_CONTADOR_UPDATE;
/
----------------------------------------------------------------
-- Script para borra un registr en la tabla MODELO_CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_modelo_contador_delete 
	
	Funcionalidad:				Borra un registro en la tabla MODELO_CONTADOR 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					MODELO			STRING			'R7g86'				
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Tipo de dato no esperado
					4-- Error desconocido	
				    1-- Campos nulos
					3-- Modelo encontado  en la tabla contadores
				
	Ejemplo de uso:			p_modelo_contador_delete('R7g86');

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_MODELO_CONTADOR_DELETE 
(
  MODELO IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 
  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  existe_modelo EXCEPTION;

  NUM_MODELOS NUMBER;
  M VARCHAR2(20);
BEGIN

  NUM_MODELOS := 0;

   -- Comprobacion de los atributos que no pueden ser nulos
  IF (MODELO IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  M:=MODELO;
  
  -- Controlamos que esta clave no se utilice en tablas dependientes
  -- TABLA CONTADOR
  SELECT  COUNT(COD_CONTADOR)
  INTO    NUM_MODELOS 
  FROM    CONTADOR
  WHERE   MODELO = M;
  
  IF (NUM_MODELOS>0) THEN
    RAISE existe_modelo;
  END IF;
  
  -- Borramos de la tabla
  DELETE FROM MODELO_CONTADOR 
  WHERE MODELO = M;
  
    rsp_log := 'OK';
  param_entrada :=  MODELO || '|' ;
  P_LOG_INSERT('P_MODELO_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
 
  
   -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  MODELO || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  WHEN existe_modelo THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: El modelo se est usando en contadores';
      rsp := 'ERROR:3';
      param_entrada :=  MODELO || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  MODELO || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  MODELO || '|' ;
      P_LOG_INSERT('P_MODELO_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
END P_MODELO_CONTADOR_DELETE;
/
----------------------------------------------------------------
-- Script para actualizar un registr en la tabla LINEA_COMUNICA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_linea_comunica_update
	
	Funcionalidad:				Actualiza un registro en la tabla LINEA_COMUNICA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO	
					COD_LINEA		NUMBER			125 
					COD_CENTRAL		NUMBER			587
					CAPACIDAD_MAX	NUMBER			895000
															
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- No se ha encontrado o la linea o la central 
					4-- Error desconocido	
				    5-- Campos nulos
				
	Ejemplo de uso:			p_linea_comunica_update(125, 587, 895000, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_LINEA_COMUNICA_UPDATE 
(
  COD_LINEA IN NUMBER  
, CAPACIDAD_MAX IN NUMBER  
, COD_CENTRAL IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  COD_CENTRAL2 NUMBER;
  COD_LINEA2 NUMBER;
  CAPACIDAD_MAX2 NUMBER;
  CL NUMBER;
BEGIN
  
    -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_LINEA IS NULL) OR (COD_CENTRAL IS NULL) OR (CAPACIDAD_MAX IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  
  CAPACIDAD_MAX2:= CAPACIDAD_MAX;
  COD_CENTRAL2 := COD_CENTRAL;
  CL := COD_LINEA;
  
  -- Comprobamos que la central de produccion existe
  SELECT  COD_CENTRAL
  INTO    COD_CENTRAL2
  FROM    CENTRAL_PRODUCCION 
  WHERE   COD_CENTRAL = COD_CENTRAL2;
  
  -- Comprobamos que existe ese  registro en la tabla de LINEA_COMUNICA
  SELECT  COD_LINEA
  INTO    COD_LINEA2
  FROM    LINEA_COMUNICA
  WHERE   COD_LINEA = CL;
  
  --Realizamos el update
  UPDATE  LINEA_COMUNICA
  SET     COD_CENTRAL = COD_CENTRAL2,
          CAPACIDAD_MAX  = CAPACIDAD_MAX2
  WHERE   COD_LINEA = CL;
  
   rsp_log := 'OK';
  param_entrada := COD_LINEA || '|' || COD_CENTRAL || '|' || CAPACIDAD_MAX || '|' ;
  P_LOG_INSERT('P_LINEA_COMUNICA_UPDATE', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_LINEA || '|' || COD_CENTRAL || '|' || CAPACIDAD_MAX || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_LINEA || '|' || COD_CENTRAL || '|' || CAPACIDAD_MAX || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado la linea o la central.';
	    rsp := 'ERROR:3';
      param_entrada := COD_LINEA || '|' || COD_CENTRAL || '|' || CAPACIDAD_MAX || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_LINEA || '|' || COD_CENTRAL || '|' || CAPACIDAD_MAX || '|' ;
      P_LOG_INSERT('P_TIPO_CENTRAL_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_LINEA || '|' || COD_CENTRAL || '|' || CAPACIDAD_MAX || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
   
  
END P_LINEA_COMUNICA_UPDATE;
/
----------------------------------------------------------------
-- Script para borrar un registro en la tabla LINEA_COMUNICA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_linea_comunica_delete 
	
	Funcionalidad:				Borra un registro en la tabla LINEA_COMUNICA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO	
					COD_LINEA		NUMBER			125 
																				
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:					
					2-- Tipo de dato no esperado
					3-- El cod_linea se est usando en central de distribucion  
					4-- Error desconocido	
				    1-- Campos nulos
				
	Ejemplo de uso:			p_linea_comunica_delete(125, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_LINEA_COMUNICA_DELETE 
(
  COD_LINEA IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  existe_cd EXCEPTION;
  
  NUM_CD NUMBER;
  CL NUMBER;
BEGIN
   
   NUM_CD := 0;

   -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_LINEA IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  CL := COD_LINEA; 
  -- Controlamos que esta clave no se utilice en tablas dependientes
  -- TABLA CENTRAL_DISTRIBUCION 
  SELECT  COUNT(COD_CENTRAL)
  INTO    NUM_CD
  FROM    CENTRAL_DISTRIBUCION
  WHERE   COD_LINEA = CL;
  
  IF (NUM_CD>0) THEN
    RAISE existe_cd;
  END IF;
  
  -- Borramos de la tabla
  DELETE FROM LINEA_COMUNICA 
  WHERE COD_LINEA = CL;
  
    rsp_log := 'OK';
  param_entrada :=  COD_LINEA || '|' ;
  P_LOG_INSERT('P_LINEA_COMUNICA_DELETE', param_entrada, rsp_log, rsp_log_out);
 
  
   -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  COD_LINEA || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  WHEN existe_cd THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: El cod_linea se est usando en CD';
      rsp := 'ERROR:3';
      param_entrada :=  COD_LINEA || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  COD_LINEA || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  COD_LINEA || '|' ;
      P_LOG_INSERT('P_LINEA_COMUNICA_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
  
END P_LINEA_COMUNICA_DELETE;
/

----------------------------------------------------------------
-- Script para actualizar un registro en la tabla HIST_LECTURA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_lectura_update
	
	Funcionalidad:				Actualiza un registro en la tabla HIST_LECTURA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CONTADOR	NUMBER			12
					FECHA			DATE			'12/02/2012'
					LECTURA			NUMBER			257
					MODO			STRING			'P'
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- No se ha encontrado el registro a actualizar 
					4-- Error desconocido	
				    5-- Campos nulos
				
	Ejemplo de uso:			p_hist_lectura_update(12, '12/02/2012', 257, 'P', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_HIST_LECTURA_UPDATE 
(
  COD_CONTADOR IN NUMBER  
, FECHA IN DATE  
, LECTURA IN NUMBER  
, MODO IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  no_existe_modo EXCEPTION;

  MODO2 VARCHAR2(1);
  COD_CONTADOR2 NUMBER;
  CONTADOR NUMBER;
  LECTURA2 NUMBER;
  FECHA2 DATE;

BEGIN

   -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CONTADOR IS NULL) OR (FECHA IS NULL) OR (LECTURA IS NULL) OR (MODO IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  -- Pasamos a mayus
  MODO2 	:= UPPER(TRIM(MODO));	
  FECHA2  := FECHA;
  CONTADOR := COD_CONTADOR;
  LECTURA2 := LECTURA;
  
  IF (MODO2<> 'P') AND (MODO2<>'T') THEN
    RAISE no_existe_modo;
  END IF;
  
  -- Comprobamos que existe ese  registro en la tabla de HIST_LECTURA
  SELECT  COD_CONTADOR
  INTO    COD_CONTADOR2 
  FROM    HIST_LECTURA
  WHERE   COD_CONTADOR = CONTADOR 
  AND     FECHA   = FECHA2;
  
   --Realizamos el update
  UPDATE  HIST_LECTURA 
  SET     LECUTRA = LECTURA2,
          MODO  = MODO2
  WHERE   COD_CONTADOR = CONTADOR 
  AND     FECHA = FECHA2;
  
  rsp_log := 'OK';
  param_entrada := COD_CONTADOR || '|' || FECHA || '|' || LECTURA || '|' || MODO || '|' ;
  P_LOG_INSERT('P_HIST_LECTURA_UPDATE', param_entrada, rsp_log, rsp_log_out);
  
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CONTADOR || '|' || FECHA || '|' || LECTURA || '|' || MODO || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CONTADOR || '|' || FECHA || '|' || LECTURA || '|' || MODO || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el registro a actualizar';
	    rsp := 'ERROR:3';
      param_entrada := COD_CONTADOR || '|' || FECHA || '|' || LECTURA || '|' || MODO || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_CONTADOR || '|' || FECHA || '|' || LECTURA || '|' || MODO || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CONTADOR || '|' || FECHA || '|' || LECTURA || '|' || MODO || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_HIST_LECTURA_UPDATE;
/

----------------------------------------------------------------
-- Script para borrar un registro en la tabla HIST_LECTURA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_lectura_delete 
	
	Funcionalidad:				Borra un registro en la tabla HIST_LECTURA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CONTADOR	NUMBER			12
					FECHA			DATE			'12/02/2012'
															
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Tipo de dato no esperado
					3-- Error desconocido	
				    1-- Campos nulos
				
	Ejemplo de uso:			p_hist_lectura_delete(12, '12/02/2012', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_HIST_LECTURA_DELETE 
(
  FECHA IN DATE  
, COD_CONTADOR IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  LECTURA   NUMBER;
  CONTADOR NUMBER;
  FECHA2 DATE;
  
BEGIN
  
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (FECHA IS NULL) OR (COD_CONTADOR IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  CONTADOR := COD_CONTADOR;
  FECHA2 := FECHA;
  
  -- Cogemos la lectura que tenia almacenada
  SELECT 	LECUTRA
  INTO		LECTURA
  FROM		HIST_LECTURA
  WHERE 	COD_CONTADOR = CONTADOR
  AND 		FECHA = FECHA2;
  
   -- Borramos de la tabla
  DELETE FROM HIST_LECTURA 
  WHERE FECHA = FECHA2
  AND COD_CONTADOR = CONTADOR;
  
  --Actualizamos el acumunlador del contador
  UPDATE CONTADOR
  SET ACUMULADOR = ACUMULADOR - LECTURA 
  WHERE COD_CONTADOR = CONTADOR;
  
  rsp_log := 'OK';
  param_entrada :=  FECHA || '|' || COD_CONTADOR || '|' ;
  P_LOG_INSERT('P_HIST_LECTURA_DELETE', param_entrada, rsp_log, rsp_log_out);
  
   -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  FECHA || '|' || COD_CONTADOR || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
   
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  FECHA || '|' || COD_CONTADOR || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  FECHA || '|' || COD_CONTADOR || '|' ;
      P_LOG_INSERT('P_HIST_LECTURA_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_HIST_LECTURA_DELETE;
/

----------------------------------------------------------------
-- Script para insertar en la tabla CENTRAL_DISTRIBUCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_central_distribucion_insert
	
	Funcionalidad:				Inserta un registro en la tabla CENTRAL_DISTRIBUCION 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DIRECCION	    STRING        	'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					ENERGIA_MAX		NUMBER(20,2)	100
					ULTIMA_INSPECCION	DATE		01/02/2012
					COD_LINEA		NUMBER			1	
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Clave de la tabla duplicada
					3-- Tipo de dato no esperado
					4-- Error desconocido
					5-- No encontrado el tipo de central

	Ejemplo de uso:			p_central_distribucion_insert('Pza.Espaa','Madrid','Espaa', 100, 01/02/2012, 1,  rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CENTRAL_DISTRIBUCION_INSERT 
(
  DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, COD_LINEA IN NUMBER  
, ENERGIA_MAX IN NUMBER  
, ULTIMA_INSPECCION IN DATE  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  COD_LINEA2 NUMBER;
  COD NUMBER;
    
  DIRECCION2 VARCHAR2(40);
  LOCALIDAD2 VARCHAR2(15);
  PAIS2 VARCHAR2(15);
  
  ENERGIA_MAX2 NUMBER;
  ULTIMA_INSPECCION2 DATE;

BEGIN
    -- Comprobacion de los atributos que no pueden ser nulos
  IF (ENERGIA_MAX IS NULL) OR (COD_LINEA IS NULL ) THEN
    RAISE campos_nulos;
  END IF;
  
  COD:= COD_LINEA; 
  
   -- Comprobamos que el cdigo de linea existe en suu tabla 
  SELECT  COD_LINEA 
  INTO    COD_LINEA2 
  FROM    LINEA_COMUNICA
  WHERE   COD_LINEA = COD;
  
    -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DIRECCION2 	:= UPPER(TRIM(DIRECCION));	
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
	PAIS2 	:= UPPER(TRIM(PAIS));	
  ULTIMA_INSPECCION2 := ULTIMA_INSPECCION;
  ENERGIA_MAX2 := ENERGIA_MAX;
  
    -- Realizamos el insert
  INSERT INTO CENTRAL_DISTRIBUCION 
  (COD_CENTRAL,
   DIRECCION      ,
   LOCALIDAD     ,
   PAIS ,
   ENERGIA_MAX,
   ULTIMA_INSPECCION,
   COD_LINEA)
  values 
  (SEQ_COD_CENTRAL_DIST.NextVal,
   DIRECCION2,
   LOCALIDAD2     ,
   PAIS2 ,
   ENERGIA_MAX2,
   ULTIMA_INSPECCION2,
   COD);
  
   rsp_log := 'OK';
   param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || COD_LINEA || '|';
  P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_INSERT', param_entrada, rsp_log, rsp_log_out);
   
  
  -- Excepciones
  EXCEPTION
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || COD_LINEA || '|';
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:2';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || COD_LINEA || '|';
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:3';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || COD_LINEA || '|';
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el cdigo de lineal';
	    rsp := 'ERROR:5';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || COD_LINEA || '|';
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := DIRECCION2 || '|' || LOCALIDAD2 || '|' || PAIS2 || '|'|| ENERGIA_MAX || '|' || ULTIMA_INSPECCION || '|' || COD_LINEA || '|';
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_INSERT', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_CENTRAL_DISTRIBUCION_INSERT;
/

----------------------------------------------------------------
-- Script para actualizar en la tabla CENTRAL_DISTRIBUCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_central_distribucion_update
	
	Funcionalidad:				Actualiza un registro en la tabla CENTRAL_DISTRIBUCION 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO	
					COD_CENTRAL		NUMBER			1
					DIRECCION	    STRING        	'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					ENERGIA_MAX		NUMBER(20,2)	100
					ULTIMA_INSPECCION	DATE		01/02/2012
					COD_LINEA		NUMBER			1	
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					5-- Campos nulos
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- No encontrado el codigo de la linea

	Ejemplo de uso:			p_central_distribucion_update(1, 'Pza.Espaa','Madrid','Espaa', 100, 01/02/2012, 1,  rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CENTRAL_DISTRIBUCION_UPDATE 
(
  COD_CENTRAL IN NUMBER  
, DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, COD_LINEA IN NUMBER  
, ENERGIA_MAX IN NUMBER  
, ULTIMA_INSPECCION IN DATE  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DIRECCION2 VARCHAR2(40);
  LOCALIDAD2 VARCHAR2(15);
  PAIS2 VARCHAR2(15);
  
  COD_LINEA2 NUMBER;
  COD NUMBER;
  COD_CENTRAL2 NUMBER;
  
  ENERGIA_MAX2 NUMBER;
  ULTIMA_INSPECCION2 DATE;
  
BEGIN
  
    -- Comprobacion de los atributos que no pueden ser nulos
  IF (ENERGIA_MAX IS NULL) OR (COD_LINEA IS NULL ) THEN
    RAISE campos_nulos;
  END IF;
  
  COD:= COD_LINEA;
  COD_CENTRAL2:= COD_CENTRAL;
  
   -- Comprobamos que el cdigo de linea existe en suu tabla 
  SELECT  COD_LINEA 
  INTO    COD_LINEA2 
  FROM    LINEA_COMUNICA
  WHERE   COD_LINEA = COD;
  
    -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DIRECCION2 	:= UPPER(TRIM(DIRECCION));	
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
	PAIS2 	    := UPPER(TRIM(PAIS));	
  
  ENERGIA_MAX2 :=   ENERGIA_MAX;
  ULTIMA_INSPECCION2 := ULTIMA_INSPECCION;
  
   --Realizamos el update
  UPDATE  CENTRAL_DISTRIBUCION
  SET     DIRECCION = DIRECCION2,
          LOCALIDAD  = LOCALIDAD2,
          PAIS  = PAIS2,
          COD_LINEA = COD,
          ENERGIA_MAX = ENERGIA_MAX2,
          ULTIMA_INSPECCION = ULTIMA_INSPECCION2 
  WHERE   COD_CENTRAL = COD_CENTRAL2;
  
  rsp_log := 'OK';
  param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|' ;
  P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
   
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado la lnea.';
	    rsp := 'ERROR:3';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_CENTRAL_DISTRIBUCION_UPDATE;
/

----------------------------------------------------------------
-- Script para borrar un registro en la tabla CENTRAL_DISTRIBUCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_central_distribucion_delete 
	
	Funcionalidad:				Borra un registro en la tabla CENTRAL_DISTRIBUCION 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO	
					COD_CENTRAL		NUMBER			1					
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- Central usandose en tablas dependientes 

	Ejemplo de uso:			p_central_distribucion_delete(1, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CENTRAL_DISTRIBUCION_DELETE 
(
  COD_CENTRAL IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  existe_contador EXCEPTION;
  
  NUM_CONTADOR NUMBER;
  NUM_CENTRAL NUMBER;
  
  COD NUMBER;
  
BEGIN
  
  NUM_CONTADOR := 0;
  
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CENTRAL IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  COD:= COD_CENTRAL;
  
  -- Controlamos que esta clave no se utilice en tablas dependientes
  -- TABLA CONTADOR_CENTRAL 
  SELECT  COUNT(COD_CONTADOR)
  INTO    NUM_CONTADOR  
  FROM    CONTADOR_CENTRAL 
  WHERE   COD_CENTRAL = COD;
  
  IF (NUM_CONTADOR>0) THEN
    RAISE existe_contador;
  END IF;
  
  -- TABLA HIST_ENERGIA_EMITIDA
  SELECT  COUNT(COD_CENTRAL)
  INTO    NUM_CENTRAL  
  FROM    HIST_ENERGIA_EMITIDA 
  WHERE   COD_CENTRAL = COD;
  
  IF (NUM_CENTRAL>0) THEN
    RAISE existe_contador;
  END IF;
  
   -- Borramos de la tabla
  DELETE FROM CENTRAL_DISTRIBUCION 
  WHERE COD_CENTRAL = COD;
  
  rsp_log := 'OK';
  param_entrada :=  COD_CENTRAL || '|' ;
  P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_DELETE', param_entrada, rsp_log, rsp_log_out);
   
  
  -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  WHEN existe_contador THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La central se est usando en dependientes';
      rsp := 'ERROR:3';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_DISTRIBUCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
  
END P_CENTRAL_DISTRIBUCION_DELETE;
/
----------------------------------------------------------------
-- Script para actualizar un registro en la tabla CENTRAL_PRODUCCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_central_produccion_update
	
	Funcionalidad:				Actualiza un registro en la tabla CENTRAL_PRODUCCION 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO
					COD_CENTRAL		NUMBER			1	
					DIRECCION	    STRING        	'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					ENERGIA_MAX		NUMBER(20,2)	100
					ULTIMA_INSPECCION	DATE		01/02/2012
					TIPO_CENTRAL	NUMBER(1)		1	
					PROPIEDAD1		NUMBER(10)		0	
					PROPIEDAD2		NUMBER(10)		0

	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					5-- Campos nulos
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- No encontrado el tipo de central

	Ejemplo de uso:			p_central_produccion_update(1,'Pza.Espaa','Madrid','Espaa', 100, 01/02/2012, 1, 15, 0, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CENTRAL_PRODUCCION_UPDATE 
(
  COD_CENTRAL IN NUMBER  
, DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, ENERGIA_MAX IN NUMBER  
, ULTIMA_INSPECCION IN DATE  
, TIPO_CENTRAL IN NUMBER  
, PROPIEDAD1 IN NUMBER  
, PROPIEDAD2 IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DIRECCION2 VARCHAR2(40);
  LOCALIDAD2 VARCHAR2(15);
  PAIS2 VARCHAR2(15);
  
  TIPO_CENTRAL2 NUMBER;
  
  ENERGIA_MAX2 NUMBER;
  ULTIMA_INSEPCCION2 DATE;
  PROPIEDAD12 NUMBER;
  PROPIEDAD22 NUMBER;
  
  COD NUMBER;
  
BEGIN
  
    -- Comprobacion de los atributos que no pueden ser nulos
  IF (ENERGIA_MAX IS NULL) OR (TIPO_CENTRAL IS NULL ) OR (COD_CENTRAL IS NULL ) THEN
    RAISE campos_nulos;
  END IF;
  
  COD:=COD_CENTRAL;
  TIPO_CENTRAL2:= TIPO_CENTRAL;
  ENERGIA_MAX2:= ENERGIA_MAX;
  ULTIMA_INSEPCCION2:= ULTIMA_INSPECCION;
  PROPIEDAD12:= PROPIEDAD1;
  PROPIEDAD22:= PROPIEDAD2;
  
   -- Comprobamos que el cdigo de linea existe en suu tabla 
  SELECT  TIPO_CENTRAL 
  INTO    TIPO_CENTRAL2 
  FROM    TIPO_CENTRAL
  WHERE   TIPO_CENTRAL = TIPO_CENTRAL2;
  
    -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DIRECCION2 	:= UPPER(TRIM(DIRECCION));	
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
	PAIS2 	    := UPPER(TRIM(PAIS));	
  
   --Realizamos el update
  UPDATE  CENTRAL_PRODUCCION 
  SET     DIRECCION = DIRECCION2,
          LOCALIDAD  = LOCALIDAD2,
          PAIS  = PAIS2,
          TIPO_CENTRAL = TIPO_CENTRAL2,
          ENERGIA_MAX = ENERGIA_MAX2,
          ULTIMA_INSPECCION = ULTIMA_INSEPCCION2,
          PROPIEDAD1 = PROPIEDAD12,
          PROPIEDAD2 = PROPIEDAD22  
  WHERE   COD_CENTRAL = COD;
  
   rsp_log := 'OK';
   param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|'|| PROPIEDAD2 || '|'|| PROPIEDAD1 || '|' ;
  P_LOG_INSERT('P_CENTRAL_PRODUCCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
   
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|'|| PROPIEDAD2 || '|'|| PROPIEDAD1 || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|'|| PROPIEDAD2 || '|'|| PROPIEDAD1 || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el tipo de central.';
	    rsp := 'ERROR:3';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|'|| PROPIEDAD2 || '|'|| PROPIEDAD1 || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|'|| PROPIEDAD2 || '|'|| PROPIEDAD1 || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CENTRAL ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || ENERGIA_MAX || '|'|| ULTIMA_INSPECCION || '|'|| PROPIEDAD2 || '|'|| PROPIEDAD1 || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_CENTRAL_PRODUCCION_UPDATE;
/

----------------------------------------------------------------
-- Script para borrar un registro en la tabla CENTRAL_PRODUCCION
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_central_produccion_delete 
	
	Funcionalidad:				Borra un registro en la tabla CENTRAL_PRODUCCION 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO
					COD_CENTRAL		NUMBER			1	
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- Central usndose en dependientes 

	Ejemplo de uso:			p_central_produccion_delete(1, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CENTRAL_PRODUCCION_DELETE 
(
  COD_CENTRAL IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  existe_central EXCEPTION;
  
  NUM_LINEAS NUMBER;
  NUM_CENTRAL NUMBER;
  
  COD NUMBER;
  
BEGIN
  
  NUM_LINEAS:=0;
  NUM_CENTRAL:=0;
  
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CENTRAL IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  COD:= COD_CENTRAL;
  
  -- Controlamos que esta clave no se utilice en tablas dependientes
  -- TABLA CONTADOR_CENTRAL 
  SELECT  COUNT(COD_LINEA)
  INTO    NUM_LINEAS  
  FROM    LINEA_COMUNICA 
  WHERE   COD_CENTRAL = COD;
  
  IF (NUM_LINEAS>0) THEN
    RAISE existe_central;
  END IF;
  
  -- TABLA HIST_ENERGIA_EMITIDA
  SELECT  COUNT(FECHA)
  INTO    NUM_CENTRAL  
  FROM    HIST_ENERGIA_PRODUCIDA 
  WHERE   COD_CENTRAL = COD;
  
  IF (NUM_CENTRAL>0) THEN
    RAISE existe_central;
  END IF;
  
   -- Borramos de la tabla
  DELETE FROM CENTRAL_PRODUCCION 
  WHERE COD_CENTRAL = COD;
  
 rsp_log := 'OK';
   param_entrada :=  COD_CENTRAL || '|' ;
  P_LOG_INSERT('P_CENTRAL_PRODUCCION_DELETE', param_entrada, rsp_log, rsp_log_out);
   
  
  -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  WHEN existe_central THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La central se est usando en dependientes';
      rsp := 'ERROR:3';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CENTRAL_PRODUCCION_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
END P_CENTRAL_PRODUCCION_DELETE;
/
----------------------------------------------------------------
-- Script para actualizar un registr en la tabla CLIENTE
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_cliente_update
	
	Funcionalidad:				Actualiza un registro en la tabla CLIENTE 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DNI_NIF		    STRING        	'12345678X'
					DIRECCION		STRING			'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					CORREO			STRING			'prueba@gmail.com'
					TELEFONO		STRING			'976666666'
					DENOMINACION	STRING			'FEDERICO GONZALEZ'	
					CONTACTO		STRING			'FEDERICO'	
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					5-- Campos nulos
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					4-- Error desconocido
				
	Ejemplo de uso:			p_cliente_update('12345678X', 'Pza.Espaa','Madrid','Espaa','prueba@gmail.com', '976666666','FEDERICO GONZALEZ', 'FEDERICO', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CLIENTE_UPDATE 
(
  DNI_NIF IN VARCHAR2  
, DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, CORREO IN VARCHAR2  
, TELEFONO IN VARCHAR2  
, DENOMINACION IN VARCHAR2  
, CONTACTO IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DNI_NIF2 VARCHAR2(12);
  DIRECCION2 VARCHAR2(40);  
  LOCALIDAD2 VARCHAR2(15);  
  PAIS2 VARCHAR2(15);
  CORREO2 VARCHAR2(30);
  TELEFONO2 VARCHAR2(9);
  DENOMINACION2 VARCHAR2(50);
  CONTACTO2 VARCHAR2(50);
  
   D VARCHAR2(12);
  
BEGIN
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (DNI_NIF IS NULL) OR (DENOMINACION IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
   -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DNI_NIF2 	:= UPPER(TRIM(DNI_NIF));	
	DIRECCION2 	:= UPPER(TRIM(DIRECCION));	
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
 	PAIS2 	:= UPPER(TRIM(PAIS));	
	CORREO2 	:= UPPER(TRIM(CORREO));	
	TELEFONO2 	:= UPPER(TRIM(TELEFONO));	
  DENOMINACION2 	:= UPPER(TRIM(DENOMINACION));	
	CONTACTO2 	:= UPPER(TRIM(CONTACTO));	
  
  D:= DNI_NIF2;
  
  UPDATE  CLIENTE
  SET     DIRECCION = DIRECCION2,
          LOCALIDAD  = LOCALIDAD2,
          PAIS  = PAIS2,
          CORREO = CORREO2,
          TELEFONO = TELEFONO2,
          DENOMINACION = DENOMINACION2,
          CONTACTO = CONTACTO2 
  WHERE   DNI_NIF = D;
  
  rsp_log := 'OK';
   param_entrada :=  DNI_NIF || '|' ;
  P_LOG_INSERT('P_CLIENTE_UPDATE', param_entrada, rsp_log, rsp_log_out);
 
    -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := DNI_NIF ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || CORREO || '|'|| TELEFONO || '|'|| DENOMINACION || '|'|| CONTACTO || '|' ;
      P_LOG_INSERT('P_CLIENTE_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := DNI_NIF ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || CORREO || '|'|| TELEFONO || '|'|| DENOMINACION || '|'|| CONTACTO || '|' ;
      P_LOG_INSERT('P_CLIENTE_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := DNI_NIF ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || CORREO || '|'|| TELEFONO || '|'|| DENOMINACION || '|'|| CONTACTO || '|' ;
      P_LOG_INSERT('P_CLIENTE_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := DNI_NIF ||'|'|| DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|' || CORREO || '|'|| TELEFONO || '|'|| DENOMINACION || '|'|| CONTACTO || '|' ;
      P_LOG_INSERT('P_CLIENTE_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  


END P_CLIENTE_UPDATE;
/
----------------------------------------------------------------
-- Script para borrar un registro en la tabla CLIENTE
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_cliente_delete
	
	Funcionalidad:				Borra un registro en la tabla CLIENTE 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					DNI_NIF		    STRING        	'12345678X'
					
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- Existe un contrato con este DNI_NIF 
				
	Ejemplo de uso:			p_cliente_delete('12345678X', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CLIENTE_DELETE 
(
  DNI_NIF IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  existe_contrato EXCEPTION;

  NUM_CONTRATOS NUMBER;

  DNI_NIF2 VARCHAR2(12);
  D VARCHAR2(12);

BEGIN
  
  NUM_CONTRATOS := 0;
  
    -- Comprobacion de los atributos que no pueden ser nulos
  IF (DNI_NIF IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
   -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DNI_NIF2 	:= UPPER(TRIM(DNI_NIF));	
  
  D:= DNI_NIF2;
  
   -- Controlamos que esta clave no se utilice en tablas dependientes
  -- TABLA CONTRATO 
  SELECT  COUNT(COD_CONTRATO)
  INTO    NUM_CONTRATOS 
  FROM    CONTRATO 
  WHERE   DNI_NIF = D;
  
  IF (NUM_CONTRATOS>0) THEN
    RAISE existe_contrato;
  END IF;
  
  -- Borramos de la tabla
  DELETE FROM CLIENTE 
  WHERE DNI_NIF = D;
  
  rsp_log := 'OK';
   param_entrada :=  DNI_NIF || '|' ;
  P_LOG_INSERT('P_CLIENTE_DELETE', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  DNI_NIF || '|' ;
      P_LOG_INSERT('P_CLIENTE_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  WHEN existe_contrato THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La central se est usando en dependientes';
      rsp := 'ERROR:3';
      param_entrada :=  DNI_NIF || '|' ;
      P_LOG_INSERT('P_CLIENTE_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  DNI_NIF || '|' ;
      P_LOG_INSERT('P_CLIENTE_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  DNI_NIF || '|' ;
      P_LOG_INSERT('P_CLIENTE_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_CLIENTE_DELETE;
/

----------------------------------------------------------------
-- Script para actualizar un registro en la tabla CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contador_update
	
	Funcionalidad:				Actualiza un registro en la tabla CONTADOR 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CONTADOR	NUMBER			1
					DIRECCION		STRING			'Pza.Espaa'
					LOCALIDAD		STRING			'Madrid'
					PAIS			STRING			'Espaa'
					ACUMULADOR		NUMBER			0
					MODELO			STRING			'R6ym'					
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					5-- Campos nulos
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- contador no encontrado
				
	Ejemplo de uso:			p_contador_update(1, 'Pza.Espaa','Madrid','Espaa',0, 'R6ym', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_CONTADOR_UPDATE 
(
  COD_CONTADOR IN NUMBER  
, DIRECCION IN VARCHAR2  
, LOCALIDAD IN VARCHAR2  
, PAIS IN VARCHAR2  
, ACUMULADOR IN NUMBER  
, MODELO IN VARCHAR2  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  DIRECCION2 VARCHAR2(40);  
  LOCALIDAD2 VARCHAR2(15);  
  PAIS2 VARCHAR2(15);
  MODELO2 VARCHAR2(20);
  COD NUMBER;
  ACUMULADOR2 NUMBER;
  
BEGIN

 -- Comprobacion de los atributos que no pueden ser nulos
  IF (MODELO IS NULL) OR (COD_CONTADOR IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  COD:= COD_CONTADOR;
  
  -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DIRECCION2 	:= UPPER(TRIM(DIRECCION));	
	LOCALIDAD2 	:= UPPER(TRIM(LOCALIDAD));	
 	PAIS2 	    := UPPER(TRIM(PAIS));	
  MODELO2     := UPPER(TRIM(MODELO));	
  ACUMULADOR2 := ACUMULADOR;
  
  -- Comprobamos que existe el modelo en la tabla de modelos de contador
  SELECT  MODELO
  INTO    MODELO2 
  FROM    MODELO_CONTADOR
  WHERE   MODELO = MODELO2;
  
   --Realizamos el update
  UPDATE  CONTADOR 
  SET     DIRECCION = DIRECCION2,
          LOCALIDAD  = LOCALIDAD2,
          PAIS = PAIS2,
          MODELO = MODELO2,
          ACUMULADOR = ACUMULADOR2  
  WHERE   COD_CONTADOR = COD;
  
  rsp_log := 'OK';
  param_entrada := COD_CONTADOR || '|' || DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
  P_LOG_INSERT('P_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CONTADOR || '|' || DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CONTADOR || '|' || DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el registro a actualizar';
	    rsp := 'ERROR:3';
      param_entrada := COD_CONTADOR || '|' || DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_CONTADOR || '|' || DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CONTADOR || '|' || DIRECCION || '|' || LOCALIDAD || '|' || PAIS || '|'|| ACUMULADOR || '|' || MODELO || '|' ;
      P_LOG_INSERT('P_CONTADOR_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
END P_CONTADOR_UPDATE;
/

----------------------------------------------------------------
-- Script para borrar un registro en la tabla CONTADOR
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contador_delete
	
	Funcionalidad:				Borra un registro en la tabla CONTADOR 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CONTADOR	NUMBER			1
									
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Campos nulos
					2-- Tipo de dato no esperado
					4-- Error desconocido
					3-- Existen registros en tablas dependientes 
				
	Ejemplo de uso:			p_contador_delete(1,rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CONTADOR_DELETE 
(
  COD_CONTADOR IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 
  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  existe_contrato EXCEPTION;
  
  NUM_CONTRATOS number;
  
  COD NUMBER;
BEGIN


  NUM_CONTRATOS:=0;
 -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CONTADOR IS NULL)  THEN
    RAISE campos_nulos;
  END IF;

  COD:= COD_CONTADOR;

 -- Controlamos que esta clave no se utilice en tablas dependientes
  -- TABLA CONTRATO 
  SELECT  COUNT(COD_CONTRATO)
  INTO    NUM_CONTRATOS 
  FROM    CONTRATO 
  WHERE   COD_CONTADOR = COD;
  
  IF (NUM_CONTRATOS>0) THEN
    RAISE existe_contrato;
  END IF;
  
  -- TABLA CONTADOR_CENTRAL
  SELECT  COUNT(COD_CONTADOR)
  INTO    NUM_CONTRATOS 
  FROM    CONTADOR_CENTRAL 
  WHERE   COD_CONTADOR = COD;
  
  IF (NUM_CONTRATOS>0) THEN
    RAISE existe_contrato;
  END IF;
  
  -- TABLA HIST_LECTURA
   SELECT  COUNT(COD_CONTADOR)
  INTO    NUM_CONTRATOS 
  FROM    HIST_LECTURA 
  WHERE   COD_CONTADOR = COD;
  
  IF (NUM_CONTRATOS>0) THEN
    RAISE existe_contrato;
  END IF;
  
    -- Borramos de la tabla
  DELETE FROM CONTADOR 
  WHERE COD_CONTADOR = COD;
  
  rsp_log := 'OK';
  param_entrada :=  COD_CONTADOR || '|' ;
  P_LOG_INSERT('P_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  COD_CONTADOR || '|' ;
      P_LOG_INSERT('P_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  WHEN existe_contrato THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: El contrato se est usando en dependientes';
      rsp := 'ERROR:3';
      param_entrada :=  COD_CONTADOR || '|' ;
      P_LOG_INSERT('P_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  COD_CONTADOR || '|' ;
      P_LOG_INSERT('P_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  COD_CONTADOR || '|' ;
      P_LOG_INSERT('P_CONTADOR_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  

END P_CONTADOR_DELETE;
/

----------------------------------------------------------------
-- Script para borrar un registro en la tabla CONTADOR_CENTRAL
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contador_central_delete
	
	Funcionalidad:				Borra un registro en la tabla CONTADOR_CENTRAL 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CONTADOR	STRING			25
					COD_CENTRAL		STRING			1				
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Tipo de dato no esperado
					4-- Error desconocido	
					1-- Campos nulos 
				
	Ejemplo de uso:			p_contador_central_delete(25,1, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CONTADOR_CENTRAL_DELETE 
(
  COD_CONTADOR IN NUMBER  
, COD_CENTRAL IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  CENTRAL NUMBER;
  
BEGIN
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CONTADOR IS NULL) OR (COD_CENTRAL IS NULL)  THEN
    RAISE campos_nulos;
  END IF;
  
  CENTRAL := COD_CENTRAL;
  
     -- Borramos de la tabla
  DELETE FROM CONTADOR_CENTRAL 
  WHERE COD_CONTADOR = COD_CONTADOR
  AND COD_CENTRAL = CENTRAL;
  
  rsp_log := 'OK';
  param_entrada :=  COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
  P_LOG_INSERT('P_CONTADOR_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
 
   
  
  -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CONTADOR_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;   
  
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CONTADOR_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  COD_CONTADOR || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_CONTADOR_CENTRAL_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
END P_CONTADOR_CENTRAL_DELETE;
/

----------------------------------------------------------------
-- Script para actualizar un registr en la tabla CONTRATO
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contrato_update
	
	Funcionalidad:				Actualiza un registro en la tabla CONTRATO 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO	
					COD_CONTRATO	NUMBER			1
					DNI_NIF			STRING			'12345678X'
					COD_CONTADOR	NUMBER			1				
					FECHA_ALTA		DATE			'01/10/2009'
					FECHA_BAJA		DATE			''
					POTENCIA		NUMBER			12
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- No se ha encontrado el registro a actualizar  
					4-- Error desconocido	
				    5-- Campos nulos
				
	Ejemplo de uso:			p_contrato_update(1, '12345678X', 1, '01/10/2009','',12, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CONTRATO_UPDATE 
(
  COD_CONTRATO IN NUMBER  
, DNI_NIF IN VARCHAR2  
, COD_CONTADOR IN NUMBER  
, FECHA_ALTA IN DATE  
, FECHA_BAJA IN DATE  
, POTENCIA IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;
  
  DNI_NIF2 VARCHAR2(12);
   DNI_NIF3 VARCHAR2(12);
  COD_CONTADOR2 NUMBER;
  CONTADOR NUMBER;
  
  CONTRATO NUMBER;
  ALTA DATE;
  BAJA DATE;
  POTENCIA2 NUMBER;

BEGIN
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CONTRATO IS NULL) OR (DNI_NIF IS NULL) OR (COD_CONTADOR IS NULL) OR (POTENCIA IS NULL) OR (FECHA_ALTA IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
    -- Paso a mayus y quito los espacios de los parametros de entrada de tipo string
	DNI_NIF2 	:= UPPER(TRIM(DNI_NIF));	
  CONTADOR := COD_CONTADOR;
  ALTA := FECHA_ALTA;
  BAJA := FECHA_BAJA;
  POTENCIA2 := POTENCIA;
  CONTRATO := COD_cONTRATO;
  
  -- Comprobamos que el contador existe en la tabla de contadores
  SELECT  COD_CONTADOR
  INTO    COD_CONTADOR2 
  FROM    CONTADOR
  WHERE   COD_CONTADOR = CONTADOR;
  
   -- Comprobamos que el cliente existe en la tabla de clientes
  SELECT  DNI_NIF
  INTO    DNI_NIF3 
  FROM    CLIENTE
  WHERE   DNI_NIF = DNI_NIF2;
  
   --Realizamos el update
  UPDATE  CONTRATO 
  SET     DNI_NIF = DNI_NIF2,
          COD_CONTADOR  = CONTADOR ,
          FECHA_ALTA = ALTA,
          FECHA_BAJA = BAJA,
          POTENCIA = POTENCIA2 
  WHERE   COD_CONTRATO = CONTRATO;
  
  rsp_log := 'OK';
  param_entrada := COD_CONTRATO || '|' || COD_CONTADOR || '|' || DNI_NIF || '|' || FECHA_ALTA || '|' || FECHA_BAJA || '|'|| POTENCIA || '|' ;
  P_LOG_INSERT('P_CONTRATO_UPDATE', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CONTRATO || '|' || COD_CONTADOR || '|' || DNI_NIF || '|' || FECHA_ALTA || '|' || FECHA_BAJA || '|'|| POTENCIA || '|' ;
      P_LOG_INSERT('P_CONTRATO_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CONTRATO || '|' || COD_CONTADOR || '|' || DNI_NIF || '|' || FECHA_ALTA || '|' || FECHA_BAJA || '|'|| POTENCIA || '|' ;
      P_LOG_INSERT('P_CONTRATO_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el registro a actualizar';
	    rsp := 'ERROR:3';
      param_entrada := COD_CONTRATO || '|' || COD_CONTADOR || '|' || DNI_NIF || '|' || FECHA_ALTA || '|' || FECHA_BAJA || '|'|| POTENCIA || '|' ;
      P_LOG_INSERT('P_CONTRATO_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_CONTRATO || '|' || COD_CONTADOR || '|' || DNI_NIF || '|' || FECHA_ALTA || '|' || FECHA_BAJA || '|'|| POTENCIA || '|' ;
      P_LOG_INSERT('P_CONTRATO_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CONTRATO || '|' || COD_CONTADOR || '|' || DNI_NIF || '|' || FECHA_ALTA || '|' || FECHA_BAJA || '|'|| POTENCIA || '|' ;
      P_LOG_INSERT('P_CONTRATO_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
END P_CONTRATO_UPDATE;
/

----------------------------------------------------------------
-- Script para borrar un registro en la tabla CONTRATO
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_contrato_delete 
	
	Funcionalidad:				Borra un registro en la tabla CONTRATO 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO	
					COD_CONTRATO	NUMBER			1
					
					
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Tipo de dato no esperado
					3-- Error desconocido	
				    1-- Campos nulos
				
	Ejemplo de uso:			p_contrato_delete(1, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_CONTRATO_DELETE 
(
  COD_CONTRATO IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  CONTRATO NUMBER;
  
BEGIN
 -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CONTRATO IS NULL)  THEN
    RAISE campos_nulos;
  END IF;

  CONTRATO := COD_CONTRATO;
  
   -- Borramos de la tabla
  DELETE FROM CONTRATO 
  WHERE COD_cONTRATO = CONTRATO;
  
  rsp_log := 'OK';
  param_entrada :=  COD_CONTRATO || '|' ;
  P_LOG_INSERT('P_CONTRATO_DELETE', param_entrada, rsp_log, rsp_log_out);
 
  
  -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  COD_CONTRATO || '|' ;
      P_LOG_INSERT('P_CONTRATO_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
      
  
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  COD_CONTRATO || '|' ;
      P_LOG_INSERT('P_CONTRATO_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  COD_CONTRATO || '|' ;
      P_LOG_INSERT('P_CONTRATO_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
END P_CONTRATO_DELETE;
/

----------------------------------------------------------------
-- Script para actualizar un registro en la tabla HIST_ENERGIA_EMITIDA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_energia_emitida_update
	
	Funcionalidad:				Actualiza un registro en la tabla HIST_ENERGIA_EMITIDA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CENTRAL		NUMBER			12
					FECHA			DATE			'12/02/2012'
					LECTURA			NUMBER			257
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- No se ha encontrado el registro a actualizar 
					4-- Error desconocido	
				    5-- Campos nulos
				
	Ejemplo de uso:			p_hist_energia_emitida_UPDATE(12, '12/02/2012', 257, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_HIST_ENERGIA_EMITIDA_UPDATE 
(
  COD_CENTRAL IN NUMBER  
, FECHA IN DATE  
, LECTURA IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  COD_CENTRAL2 NUMBER;

  FECHA2 DATE;
  LECTURA2 NUMBER;
  CENTRAL NUMBER;

BEGIN
   -- Comprobacion de los atributos que no pueden ser nulos
  IF (LECTURA IS NULL) OR (COD_CENTRAL IS NULL) OR (FECHA IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  CENTRAL := COD_CENTRAL;
  FECHA2 := FECHA;
  LECTURA2 := LECTURA;
  
   -- Comprobamos que existe ese  registro en la tabla de HIST_ENERGIA_EMITIDA
  SELECT  COD_CENTRAL
  INTO    COD_CENTRAL2  
  FROM    HIST_ENERGIA_EMITIDA
  WHERE   COD_CENTRAL = CENTRAL 
  AND     FECHA   = FECHA2;
  
   --Realizamos el update
  UPDATE  HIST_ENERGIA_EMITIDA  
  SET     LECTURA = LECTURA2
  WHERE   COD_CENTRAL = CENTRAL 
  AND     FECHA = FECHA2;
  
  rsp_log := 'OK';
  param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
  P_LOG_INSERT('P_HIST_ENERGIA_E_UPDATE', param_entrada, rsp_log, rsp_log_out);
  
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el registro a actualizar';
	    rsp := 'ERROR:3';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  
  
  
END P_HIST_ENERGIA_EMITIDA_UPDATE;
/

----------------------------------------------------------------
-- Script para borrar un registro en la tabla HIST_ENERGIA_EMITIDA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_energia_emitida_delete
	
	Funcionalidad:				Borra un registro en la tabla HIST_ENERGIA_EMITIDA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CENTRAL		NUMBER			12
					FECHA			DATE			'12/02/2012'
														
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Tipo de dato no esperado
					4-- Error desconocido	
				    1-- Campos nulos
				
	Ejemplo de uso:			p_hist_energia_emitida_delete(12, '12/02/2012', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_HIST_ENERGIA_EMITIDA_DELETE 
(
  COD_CENTRAL IN NUMBER  
, FECHA IN DATE  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  CENTRAL NUMBER;
  FECHA2 DATE;

BEGIN

 -- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CENTRAL IS NULL) OR (FECHA IS NULL) THEN
    RAISE campos_nulos;
  END IF;

  CENTRAL:= COD_CENTRAL;
  FECHA2 := FECHA;

 -- Borramos de la tabla
  DELETE FROM HIST_ENERGIA_EMITIDA 
  WHERE FECHA = FECHA2
  AND COD_CENTRAL = CENTRAL;
  
  rsp_log := 'OK';
  param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
  P_LOG_INSERT('P_HIST_ENERGIA_E_D', param_entrada, rsp_log, rsp_log_out);
  
  
  
   -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_D', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
   
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_D', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_HIST_ENERGIA_E_D', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  
  

END P_HIST_ENERGIA_EMITIDA_DELETE;
/
----------------------------------------------------------------
-- Script para actualizar un registro en la tabla HIST_ENERGIA_PRODUCIDA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_energia_prod_update
	
	Funcionalidad:				Actualiza un registro en la tabla HIST_ENERGIA_PRODUCIDA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CENTRAL		NUMBER			12
					FECHA			DATE			'12/02/2012'
					LECTURA			NUMBER			257
										
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					1-- Clave de la tabla duplicada
					2-- Tipo de dato no esperado
					3-- No se ha encontrado el registro a actualizar 
					4-- Error desconocido	
				    5-- Campos nulos
				
	Ejemplo de uso:			p_hist_energia_prod_update(12, '12/02/2012', 257, rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/

create or replace
PROCEDURE P_HIST_ENERGIA_PROD_UPDATE 
(
  COD_CENTRAL IN NUMBER  
, FECHA IN DATE  
, LECTURA IN NUMBER  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  COD_CENTRAL2 NUMBER;
  FECHA2 DATE;
  LECTURA2 NUMBER;
  CENTRAL NUMBER;

BEGIN
  -- Comprobacion de los atributos que no pueden ser nulos
  IF (LECTURA IS NULL) OR (COD_CENTRAL IS NULL) OR (FECHA IS NULL) THEN
    RAISE campos_nulos;
  END IF;
  
  FECHA2 := FECHA;
  CENTRAL := COD_CENTRAL;
  LECTURA2 := LECTURA;
  
   -- Comprobamos que existe ese  registro en la tabla de HIST_ENERGIA_PRODUCIDA
  SELECT  COD_CENTRAL
  INTO    COD_CENTRAL2  
  FROM    HIST_ENERGIA_PRODUCIDA
  WHERE   COD_CENTRAL = CENTRAL
  AND     FECHA   = FECHA2;

   --Realizamos el update
  UPDATE  HIST_ENERGIA_PRODUCIDA  
  SET     LECTURA = LECTURA2
  WHERE   COD_CENTRAL = CENTRAL  
  AND     FECHA = FECHA2;
  
  rsp_log := 'OK';
  param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
  P_LOG_INSERT('P_HIST_E_P_UPDATE', param_entrada, rsp_log, rsp_log_out);
  
  
  -- Control de excepciones
   EXCEPTION
 
   WHEN DUP_VAL_ON_INDEX THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: La clave est duplicada';
	    rsp := 'ERROR:1';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_E_P_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
 
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_E_P_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN NO_DATA_FOUND THEN 
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: No se ha encontrado el registro a actualizar';
	    rsp := 'ERROR:3';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_E_P_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:5';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_E_P_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
    
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada := COD_CENTRAL || '|' || FECHA || '|' || LECTURA || '|'  ;
      P_LOG_INSERT('P_HIST_E_P_UPDATE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  

END P_HIST_ENERGIA_PROD_UPDATE;
/
----------------------------------------------------------------
-- Script para borrar un registro en la tabla HIST_ENERGIA_PRODUCIDA
----------------------------------------------------------------
/***************************************************************

	Fecha de creacin:			06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_hist_energia_prod_delete
	
	Funcionalidad:				Borra un registro en la tabla HIST_ENERGIA_PRODUCIDA 

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					COD_CENTRAL		NUMBER			12
					FECHA			DATE			'12/02/2012'
														
	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp1	    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin del log se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: nmero del error'

	Valores de los errores:
					2-- Tipo de dato no esperado
					4-- Error desconocido	
				    1-- Campos nulos
				
	Ejemplo de uso:			p_hist_energia_prod_delete(12, '12/02/2012', rsp1);

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_HIST_ENERGIA_PROD_DELETE 
(
  COD_CENTRAL IN NUMBER  
, FECHA IN DATE  
, RSP1 OUT VARCHAR2  
) AS 

  rsp VARCHAR2(25);
  rsp_log VARCHAR2(100);
  rsp_log_out VARCHAR2(100);
  param_entrada VARCHAR2(100);
  campos_nulos EXCEPTION;

  CENTRAL NUMBER;
  FECHA2 DATE;
  
BEGIN
-- Comprobacion de los atributos que no pueden ser nulos
  IF (COD_CENTRAL IS NULL) OR (FECHA IS NULL) THEN
    RAISE campos_nulos;
  END IF;

  CENTRAL := COD_CENTRAL;
  FECHA2 := FECHA;

 -- Borramos de la tabla
  DELETE FROM HIST_ENERGIA_PRODUCIDA 
  WHERE FECHA = FECHA2
  AND COD_CENTRAL = CENTRAL;
  
  rsp_log := 'OK';
  param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
  P_LOG_INSERT('P_HIST_E_P_DELETE', param_entrada, rsp_log, rsp_log_out);
  
  
   -- Excepciones
  EXCEPTION
  
    WHEN campos_nulos THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Hay campos nulos no posibles';
      rsp := 'ERROR:1';
      param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_HIST_E_P_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;      
   
    WHEN ROWTYPE_MISMATCH THEN
      -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Tipo de dato no esperado';
	    rsp := 'ERROR:2';
      param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_HIST_E_P_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;
       
    WHEN OTHERS THEN
       -- Se echan para atrs todos los cambios efectuados
      ROLLBACK;
      -- Se registra en la tabla de LOG
      rsp_log := 'ERROR: Error no controlado';
	    rsp := 'ERROR:4';
      param_entrada :=  FECHA || '|' || COD_CENTRAL || '|' ;
      P_LOG_INSERT('P_HIST_E_P_DELETE', param_entrada, rsp_log, rsp_log_out);
      DBMS_OUTPUT.PUT_LINE(rsp_log);
      -- Aplicamos los cambios del LOG
      COMMIT;  

END P_HIST_ENERGIA_PROD_DELETE;
/
