/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_e1_actualiza 
	
	Funcionalidad:				Dada una central de produccin devuelve el listado de contadores
								asociado a la central junto con su consumo, en el ao. ( lo actualiza 
								en la table e1)
								
	Parmetros de entrada: 		
								contador
								acumulador
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e1_actualiza(2,100,RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e1_actualiza (
	c_contador IN NUMBER,
  acumulador IN NUMBER, 
	resultado OUT NOCOPY Varchar2
	)
IS
  procedimiento Varchar2(80) := 'p_e1_actualiza';
  entrada Varchar2(4000) := ' ';
	salida Varchar2(4000) := ' ';
	
	err_num NUMBER;
	err_msg Varchar2(255);	
	
  noContador EXCEPTION;
	otraExcepcion EXCEPTION;	
	
  c_central NUMBER;
  
	CURSOR c_contadores IS
		select distinct lc.cod_central 
    from contador_central cc,
        central_distribucion cd,
        linea_comunica lc 
    where cc.cod_contador = 1
    and   cc.cod_central = cd.cod_central
    and   cd.cod_linea = lc.cod_linea; 

	
BEGIN
		-- Inicializacin de variables
		resultado := 'OK';
    entrada := '<' || to_char(c_contador) || '><'|| to_char(acumulador)||'>' ;
      
    -- Comprobacin de parmetros de entrada
    IF (c_contador IS NULL OR c_contador = 0) THEN
        RAISE noContador;
    END IF;
     	
		-- Borra los registros que existieran de ese contador
		DELETE 
		FROM 	E1
		WHERE COD_CONTADOR = c_contador;
		
		-- Tratamiento del cursor
		OPEN c_contadores;
		LOOP
			FETCH c_contadores INTO c_central;						
			EXIT WHEN c_contadores%NOTFOUND;
			
			INSERT INTO E1 (cod_contador, acumulador, cod_central)
			VALUES (c_contador, acumulador, c_central);
						
		END LOOP;
		CLOSE c_contadores;		
		
		-- Ejecucin correcta del procedimento
    p_log_insert(procedimiento, entrada, salida, resultado);
        
		-- Control de excepciones 
        EXCEPTION
			WHEN noContador THEN
				resultado := 'ERROR: <Codigo de contador> inexistente';
				p_log_insert(procedimiento, entrada, salida, resultado);
			WHEN otraExcepcion THEN
				resultado := 'ERROR: Error indefinido';
				p_log_insert(procedimiento, entrada, salida, resultado);
            WHEN DUP_VAL_ON_INDEX THEN
				resultado := 'ERROR: El registro E1 ya existe';
				p_log_insert(procedimiento, entrada, salida, resultado);						
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimiento, entrada, salida, resultado);
END p_e1_actualiza;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_e2_actualiza 
	
	Funcionalidad:				Dado un ao y un contador, recalcula todas los valores medios de la energia 
								consumida por todas las lineas del contador y lo actualiza en la tabla e2)
								
	Parmetros de entrada: 		
								ao
								codigo de contador
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e2_actualiza(2012,2,RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e2_actualiza (
	anio IN NUMBER,
  c_contador IN NUMBER, 
	resultado OUT NOCOPY Varchar2
	)
IS
  procedimiento Varchar2(80) := 'p_e2_actualiza';
  entrada Varchar2(4000) := ' ';
	salida Varchar2(4000) := ' ';
	
	err_num NUMBER;
	err_msg Varchar2(255);	
	
  noContador EXCEPTION;
  c_linea number;  
  consumo_medio number;
  
  CURSOR c_lineas IS
		select  cd.cod_linea  
    from    contador_central cc,
            central_distribucion cd
    where   cc.cod_contador = c_contador
    and     cc.cod_central = cd.cod_central;
  
BEGIN
		-- Inicializacin de variables
		resultado := 'OK';
    entrada := '<' || to_char(anio) || '><'|| to_char(c_contador)||'>' ;
      
    -- Comprobacin de parmetros de entrada
    IF (c_contador IS NULL OR c_contador = 0) THEN
        RAISE noContador;
    END IF;
    
    -- Tratamiento del cursor
		OPEN c_lineas;
		LOOP
			FETCH c_lineas INTO c_linea;						
			EXIT WHEN c_lineas%NOTFOUND;
			
      -- borramos los datos de e2 para esa linea, ese ao
      delete 
      from e2
      where cod_linea = c_linea
      and   anyo =anio;
      
      -- obtenemos el nuevo valor
      SELECT NVL(SUM(CONSUMO_MEDIO),1)
      into consumo_medio
      FROM (
        SELECT  H.COD_CONTADOR, SUM(H.LECUTRA) AS CONSUMO, COUNT(DISTINCT CD1.COD_LINEA), NVL(SUM(H.LECUTRA),1)/NVL(COUNT(DISTINCT CD1.COD_LINEA),1) AS CONSUMO_MEDIO
        FROM    CENTRAL_DISTRIBUCION CD,
                CONTADOR_CENTRAL CC,
                HIST_LECTURA_COPY H,
                CONTADOR_CENTRAL CC1,
                CENTRAL_DISTRIBUCION CD1
        WHERE   CD.COD_LINEA = c_linea
        AND     CD.COD_CENTRAL = CC.COD_CENTRAL
        AND     H.COD_CONTADOR = CC.COD_CONTADOR
        AND     TO_CHAR(H.FECHA , 'YYYY') = anio
        AND     CC1.COD_CONTADOR = H.COD_CONTADOR 
        AND     CD1.COD_CENTRAL = CC1.COD_CENTRAL 
        GROUP BY H.COD_CONTADOR
      );
      
      if (anio >0)  then
          IF (consumo_medio=1) THEN
            consumo_medio := 0;
          END IF;
          
          -- insertamos en la tabla
          INSERT INTO E2 (cod_linea, valor_medio, anyo)
          VALUES (c_linea, consumo_medio, anio);
      end if;						
		END LOOP;
		CLOSE c_lineas;		
		
		-- Ejecucin correcta del procedimento
    p_log_insert(procedimiento, entrada, salida, resultado);
        
		-- Control de excepciones 
        EXCEPTION
			WHEN noContador THEN
				resultado := 'ERROR: <Codigo de contador> inexistente';
				p_log_insert(procedimiento, entrada, salida, resultado);
		  WHEN DUP_VAL_ON_INDEX THEN
				resultado := 'ERROR: El registro E2 ya existe';
				p_log_insert(procedimiento, entrada, salida, resultado);						
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimiento, entrada, salida, resultado);
END p_e2_actualiza;
/
/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_e3_actualiza 
	
	Funcionalidad:				Calcula la lnea mas cargada a nivel de energia consumida
								y la actualiza en la tabla e3
								
	Parmetros de entrada: 		
								
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e3_actualiza(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e3_actualiza (
	resultado OUT NOCOPY Varchar2
	)
IS
  procedimiento Varchar2(80) := 'p_e3_actualiza';
  entrada Varchar2(4000) := ' ';
  salida Varchar2(4000) := ' ';
	
  err_num NUMBER;
  err_msg Varchar2(255);	
	
  c_linea number;  
  
BEGIN
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<>' ;
    			
    -- borramos los datos de e2 para esa linea, ese ao
    delete 
    from e3;
      
    -- obtenemos el nuevo valor
    select linea 
	into c_linea 
	from (
	  select  linea, sum(consumo_contador)
	  from (
		select  cd.cod_linea as linea, cc.cod_contador, sum(h.lecutra) as consumo, count(cd.cod_linea) over(partition by cc.cod_contador) as num_lineas,
				sum(h.lecutra)/(count(cd.cod_linea) over(partition by cc.cod_contador) ) as consumo_contador
		from    central_distribucion cd,
				contador_central cc,
				hist_lectura_copy h
		where   cd.cod_central = cc.cod_central
		and     cc.cod_contador = h.cod_contador
		group by cd.cod_linea, cc.cod_contador
		order by cc.cod_contador, cd.cod_linea
	  )
	  group by linea
	  order by sum(consumo_contador) desc
	)
	where rownum = 1; 
	
    -- insertamos en la tabla
	INSERT INTO E3 (cod_linea)
	VALUES (c_linea);
     		
		
	-- Ejecucin correcta del procedimento
    p_log_insert(procedimiento, entrada, salida, resultado);
        
	-- Control de excepciones 
    EXCEPTION
	WHEN DUP_VAL_ON_INDEX THEN
		resultado := 'ERROR: El registro E2 ya existe';
		p_log_insert(procedimiento, entrada, salida, resultado);						
	WHEN OTHERS THEN
		err_num := SQLCODE;
		err_msg := SQLERRM;
		resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
		p_log_insert(procedimiento, entrada, salida, resultado);
END p_e3_actualiza;
/
/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_e4_actualiza 
	
	Funcionalidad:				Calcula el porcentaje de lineas que han superado el 50%
								de su capacidad max y actualiza e4
								
	Parmetros de entrada: 		
								ao
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e4_actualiza(2012, RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e4_actualiza (
	anio IN NUMBER,
	resultado OUT NOCOPY Varchar2
	)
IS
  procedimiento Varchar2(80) := 'p_e4_actualiza';
  entrada Varchar2(4000) := ' ';
  salida Varchar2(4000) := ' ';
	
  err_num NUMBER;
  err_msg Varchar2(255);	
	
  porcentaje number;  
  
BEGIN
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<' || to_char(anio) || '>>' ;
	
    -- borramos los datos de e2 para esa linea, ese ao
    delete 
    from e4
	where anyo = anio;
      
    -- obtenemos el nuevo valor
    select (b.lineas_50*100)/c.num_lineas as porcentaje 
	into porcentaje 
	from (
	  select  count(a.linea) as lineas_50
	  from (
		select  linea, (consumo_linea*100)/capacidad as porcentaje_consumo
		from (
		  select  capacidad, linea, sum(consumo_contador) as consumo_linea
		  from (
			select  distinct lc.capacidad_max as capacidad, cd.cod_linea as linea, cc.cod_contador,
					sum(h.lecutra) over(partition by h.cod_contador) /(count(distinct cd.cod_linea) over(partition by  cc.cod_contador)) as consumo_contador
			from    linea_comunica lc, 
					central_distribucion cd,
					contador_central cc,
					hist_lectura_copy h
			where   lc.cod_linea = cd.cod_linea
			and     cd.cod_central = cc.cod_central
			and     cc.cod_contador = h.cod_contador
			and     to_char(h.fecha, 'yyyy') = anio
		  )
		  group by linea, capacidad
		)
	  )a
	  where a.porcentaje_consumo > 50
	) b,
	(
	select count(cod_linea) as num_lineas
	from linea_comunica
	)c;
	
    -- insertamos en la tabla
	INSERT INTO E4 (anyo, porcentaje_linea)
	VALUES (anio, porcentaje);
     		
		
	-- Ejecucin correcta del procedimento
    p_log_insert(procedimiento, entrada, salida, resultado);
        
	-- Control de excepciones 
    EXCEPTION
	WHEN DUP_VAL_ON_INDEX THEN
		resultado := 'ERROR: El registro E2 ya existe';
		p_log_insert(procedimiento, entrada, salida, resultado);						
	WHEN OTHERS THEN
		err_num := SQLCODE;
		err_msg := SQLERRM;
		resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
		p_log_insert(procedimiento, entrada, salida, resultado);
END p_e4_actualiza;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_e5_actualiza 
	
	Funcionalidad:				Calcula el porcentaje de centrales de produccion que han superado el 30%
								de la produccion total en el ao
								
	Parmetros de entrada: 		
								ao
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e5_actualiza(2012, RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e5_actualiza (
	anio IN NUMBER,
	resultado OUT NOCOPY Varchar2
	)
IS
  procedimiento Varchar2(80) := 'p_e5_actualiza';
  entrada Varchar2(4000) := ' ';
  salida Varchar2(4000) := ' ';
	
  err_num NUMBER;
  err_msg Varchar2(255);	
	
  num_centrales number;  
  
BEGIN
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<' || to_char(anio) || '>>' ;
	
    -- borramos los datos de e2 para esa linea, ese ao
    delete 
    from e5
	where anyo = anio;
      
    -- obtenemos el nuevo valor
    select  count(cod_central) as num_centrales_30
	into 	num_centrales 
	from (
	  select  cod_central, produccion_central, produccion_total,
			  porce_central
	  from (        
		select  distinct cod_central, sum(lectura) over(partition by cod_central) as produccion_central, sum(lectura) over(partition by to_char(fecha, 'yyyy') ) as produccion_total,
				(sum(lectura) over(partition by cod_central) *100)/( sum(lectura) over(partition by to_char(fecha, 'yyyy') )) as porce_central        
		from    hist_energia_prod_copy
		where   to_char(fecha, 'yyyy') = anio
	  )
	  where porce_central < 30
	);

	
    -- insertamos en la tabla
	INSERT INTO E5 (anyo, num_centrales_produccion)
	VALUES (anio, num_centrales);
     		
		
	-- Ejecucin correcta del procedimento
    p_log_insert(procedimiento, entrada, salida, resultado);
        
	-- Control de excepciones 
    EXCEPTION
	WHEN DUP_VAL_ON_INDEX THEN
		resultado := 'ERROR: El registro E5 ya existe';
		p_log_insert(procedimiento, entrada, salida, resultado);						
	WHEN OTHERS THEN
		err_num := SQLCODE;
		err_msg := SQLERRM;
		resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
		p_log_insert(procedimiento, entrada, salida, resultado);
END p_e5_actualiza;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_e6_actualiza 
	
	Funcionalidad:				Calcula el top 10 de los contadores con mas consumo historicamente y
								lo inserta en e6
								
	Parmetros de entrada: 		
								
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e6_actualiza(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e6_actualiza (
	resultado OUT NOCOPY Varchar2
	)
IS
  procedimiento Varchar2(80) := 'p_e6_actualiza';
  entrada Varchar2(4000) := ' ';
  salida Varchar2(4000) := ' ';
	
  err_num NUMBER;
  err_msg Varchar2(255);	
	
  c_contador number;  
  
  CURSOR c_contadores IS
	select cod_contador
	from (
	  select  cod_Contador, sum(lecutra) as consumo
	  from    hist_lectura_copy
	  group by cod_contador
	  order by sum(lecutra) desc
	)
	where rownum <= 10;
  
BEGIN
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<>' ;
	
    -- borramos los datos de e6 
    delete 
    from e6;
      
    -- Tratamiento del cursor
	OPEN c_contadores;
	LOOP
		FETCH c_contadores INTO c_contador;						
		EXIT WHEN c_contadores%NOTFOUND;
		
		-- insertamos en la tabla
		INSERT INTO E6 (cod_contador)
		VALUES (c_contador);
					
	END LOOP;
	CLOSE c_contadores;		
	
    -- Ejecucin correcta del procedimento
    p_log_insert(procedimiento, entrada, salida, resultado);
        
	-- Control de excepciones 
    EXCEPTION
	WHEN DUP_VAL_ON_INDEX THEN
		resultado := 'ERROR: El registro E6 ya existe';
		p_log_insert(procedimiento, entrada, salida, resultado);						
	WHEN OTHERS THEN
		err_num := SQLCODE;
		err_msg := SQLERRM;
		resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
		p_log_insert(procedimiento, entrada, salida, resultado);
END p_e6_actualiza;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_e7_actualiza 
	
	Funcionalidad:				Calcula el consumno medio de todos los cliente y
								lo inserta en e7
								
	Parmetros de entrada: 		
								
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e7_actualiza(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e7_actualiza (
	resultado OUT NOCOPY Varchar2
	)
IS
  procedimiento Varchar2(80) := 'p_e7_actualiza';
  entrada Varchar2(4000) := ' ';
  salida Varchar2(4000) := ' ';
	
  err_num NUMBER;
  err_msg Varchar2(255);	
	
  consumo number;  
  dni varchar2(12);
  
  CURSOR c_clientes IS
	select c.dni_nif, sum(h.lecutra)/count(h.fecha) as consumo_medio
	from contrato c,
		hist_lectura_copy h
	where c.cod_contador = h.cod_contador
	and   h.fecha >= c.fecha_alta
	and   h.fecha <= nvl(c.fecha_baja, sysdate)
	group by c.dni_nif;
  
BEGIN
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<>' ;
	
    -- borramos los datos de e7
    delete 
    from e7;
      
    -- Tratamiento del cursor
	OPEN c_clientes;
	LOOP
		FETCH c_clientes INTO dni, consumo;						
		EXIT WHEN c_clientes%NOTFOUND;
		
		-- insertamos en la tabla
		INSERT INTO E7 (dni_nif, consumo_medio)
		VALUES (dni, consumo);
					
	END LOOP;
	CLOSE c_clientes;		
	
    -- Ejecucin correcta del procedimento
    p_log_insert(procedimiento, entrada, salida, resultado);
        
	-- Control de excepciones 
    EXCEPTION
	WHEN DUP_VAL_ON_INDEX THEN
		resultado := 'ERROR: El registro E7 ya existe';
		p_log_insert(procedimiento, entrada, salida, resultado);						
	WHEN OTHERS THEN
		err_num := SQLCODE;
		err_msg := SQLERRM;
		resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
		p_log_insert(procedimiento, entrada, salida, resultado);
END p_e7_actualiza;
/