
----------------------------------------------------------------
-- Script para actualizar las estadsticas
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/42/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	p_estadisticas
	
	Funcionalidad:			Actializa las tablas estadsticas segn el parmetro de entrada

	Parmetros de entrada:		(tabla)
					----------------------------------------------
					NOMBRE		    TIPO		      VALOR EJEMPLO		
					TABLA         STRING        'HIST_LECTURA'

	Parmetros de salida:		(rsp)
					-----------------------------------------------
					NOMBRE		TIPO		  VALOR EJEMPLO	
					rsp		    STRING		OK

	Valor de retorno:		La salida ser OK si la actualizacin de estadsticas se ha realizado correctamente.
					En caso de error se retorna: 'ERROR: numero de error'

	Valores de los errores:
					1-- 

	Ejemplo de uso:			p_estadisticas('HIST_LECTURA');

	MODIFICACIONES POSTERIORES:

					

*******************************************************************************************************/
create or replace
PROCEDURE P_ESTADISTICAS 
(  TABLA IN VARCHAR2, 
  PARAM IN VARCHAR2, 
  RESP OUT VARCHAR2) 
IS

  rsp VARCHAR2(25);
  resp_log VARCHAR2(25);
  cod_contador number;
  acumulador number;
  ll_pos number;
  fecha date;  
  anio number;
  
BEGIN 

  -- SEGUN EL VALOR QUE SE LE PASE AL PROCEDIMENTO, ES DECIR, LA TABLA QUE HA GENERADO EL TRIGGER
  -- EL PROCEDIMIENTO LLAMAR A UNA U OTRA FUNCIN, PARA ACTUALIZAR CADA UNA DE LAS ESTADISTICAS
  -- QUE DEPENDAN DE ESA TABLA

  CASE TABLA 
    WHEN 'HIST_LECTURA' THEN 
      ll_pos := INSTR(param, '||');
      
      anio:= to_number(substr(param, 1, ll_pos -1));
		  cod_contador:= to_number(substr(param, ll_pos + 2, length(param)));
            
      P_E2_ACTUALIZA(anio, cod_contador, rsp);
      P_E3_ACTUALIZA(rsp);
      P_E4_ACTUALIZA(anio, rsp);
      P_E6_ACTUALIZA(rsp);
      P_E7_ACTUALIZA(rsp);
         
    WHEN 'HIST_ENERGIA_PRODUCIDA' THEN 
      anio := to_number(param);
      P_E5_ACTUALIZA(anio, rsp);
      
    WHEN 'CONTADOR' THEN     
		  ll_pos := INSTR(param, '||');
      
      cod_contador:= to_number(substr(param, 1, ll_pos -1));
		  acumulador := to_number(substr(param, ll_pos + 2, length(param)));
            
      P_E1_ACTUALIZA(cod_contador, acumulador, rsp);
               
    ELSE  resp:= 'ERROR:1- La tabla no genera actualizacin de estadsticas.';
  END CASE;
  
  p_log_insert('P_ESTADISTICAS', TABLA, resp, resp_log);
  
END P_ESTADISTICAS;