-----------------------------------------------------------------------------------------------------------------
-- Script para crear el trigger de la tabla contador, campo acumulador, al borrar, insertar o actualizar
-----------------------------------------------------------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	TR_CONTADOR
	
	Funcionalidad:			Llama a la actualizacin de estadsticas

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/


create or replace
TRIGGER TR_CONTADOR 
AFTER INSERT OR DELETE OR UPDATE OF ACUMULADOR ON CONTADOR 
FOR EACH ROW
DECLARE
  RSP VARCHAR2(25);
  RSP2 VARCHAR2(25);
  
  param varchar2(50);
  cod_contador number;
  acumula number;
  
BEGIN
  -- SI SE MODIFICAN ALGUNOS DE LOS CAMPOS (ACUMULADOR) 
  -- LLAMAREMOS AL RECALCULO DE ESTADISTICAS PASANDOLE EL COD_CONTADOR
  
  if inserting then
    cod_contador := :new.cod_contador;
	acumula := new.acumulador;
  end if;
  
  if deleting then
    cod_contador := :old.cod_contador;
	acumula := old.acumulador;
  end if;
  
  if updating then
    cod_contador := :new.cod_contador;
	acumula := new.acumulador;
  end if;
  
  param := to_char(cod_contador) || '||' || to_char(acumula);
   
  P_ESTADISTICAS('CONTADOR', param, RSP);
  
  -- INSERTAMOS EN EL LOG
  P_LOG_INSERT('TR_CONTADOR', '', RSP, RSP2);
  
  
END;
/
-----------------------------------------------------------------------------------------------------------------
-- Script para crear el trigger de la tabla hist_lectura al insertar, borrar o actualizar
-----------------------------------------------------------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	TR_HIST_LECTURA
	
	Funcionalidad:			Llama a la actualizacin de estadsticas

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/

create or replace
TRIGGER TR_HIST_LECTURA 
AFTER INSERT OR DELETE OR UPDATE ON HIST_LECTURA
FOR EACH ROW
DECLARE
  RSP VARCHAR2(25);
  RSP2 VARCHAR2(25);
  
  param varchar2(50);
  anio number;
  cod_contador number;
  
BEGIN
  -- SI SE MODIFICAN ALGUNOS DE LOS CAMPOS 
  -- LLAMAREMOS AL RECALCULO DE ESTADISTICAS
   
  if inserting then
    cod_contador := :new.cod_contador;
    anio := to_number(to_char(:new.fecha, 'yyyy'));
  end if;
  
  if deleting then
    cod_contador := :old.cod_contador;
    anio := 0;
  end if;
  
  if updating then
    cod_contador := :new.cod_contador;
    anio := to_number(to_char(:new.fecha, 'yyyy'));
  end if;
  
  param := to_char(anio) || '||' || to_char(cod_contador);
   
  P_ESTADISTICAS('HIST_LECTURA', param, RSP);
  
  -- INSERTAMOS EN EL LOG
  P_LOG_INSERT('TR_HIST_LECTURA', '', RSP, RSP2);
  
  
END;
/
----------------------------------------------------------------
-- Script para crear el trigger de la tabla HIST_ENERGIA_PRODUCIDA al modificar
----------------------------------------------------------------

/***************************************************************

	Fecha de creacin:		06/04/2012

	Usuario de la creacin:		UOC
	
	Nombre del procedimiento:	TR_HIST_ENER_PRODUCIDA
	
	Funcionalidad:			Llama a la actualizacin de estadsticas

	MODIFICACIONES POSTERIORES:

					
*******************************************************************************************************/


 create or replace
TRIGGER TR_HIST_ENER_PRODUCIDA
AFTER INSERT OR DELETE OR UPDATE ON HIST_ENERGIA_PRODUCIDA
FOR EACH ROW
DECLARE
  RSP VARCHAR2(25);
  RSP2 VARCHAR2(25);
  
  param varchar2(50);
  anio number;
    
BEGIN
  -- SI SE MODIFICAN ALGUNOS DE LOS CAMPOS 
  -- LLAMAREMOS AL RECALCULO DE ESTADISTICAS
  
  if inserting then
    anio := to_number(to_char(:new.fecha, 'yyyy'));
  end if;
  
  if deleting then
    anio := to_number(to_char(:old.fecha, 'yyyy'));    
  end if;
  
  if updating then
    anio := to_number(to_char(:new.fecha, 'yyyy'));
  end if;
  
  param := to_char(anio);
   
  P_ESTADISTICAS('HIST_ENERGIA_PRODUCIDA', param, RSP);
  
  -- INSERTAMOS EN EL LOG
  P_LOG_INSERT('TR_HIST_ENER_PRODUCIDA', '', RSP, RSP2);
  
  
END;
/
