/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_contadores_80_porc_listado 
	
	Funcionalidad:				Dada una fecha y una ciudad, listado de todos los contadores
								donde el consumo mensual de la fecha ha superado el 80% del consumo medio
								de los contadores de la ciudad.
								
	Parmetros de entrada: 		
								ciudad
								fecha 
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_contadores_80_porc_listado('MADRID', '02/01/2012',RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/

CREATE OR REPLACE PROCEDURE p_contadores_80_porc_listado (
	ciudad IN contador.localidad%TYPE,
	fecha IN varchar2, 
    resultado OUT NOCOPY Varchar2
	)
IS
    procedimento Varchar2(80) := 'p_contadores_80_porc_listado';
    entrada Varchar2(4000) := ' ';
	noCiudad EXCEPTION;
	noFecha EXCEPTION;
	cod_contrato NUMBER(12,0);
	potencia NUMBER(12,0);
	tanto_por_cien NUMBER(10,2);
	salida Varchar2(4000) := ' ';
	err_num NUMBER;
	err_msg Varchar2(255);	 

	CURSOR c_contadores IS
		select  con.cod_contrato as cod_contrato, con.potencia, (a.lectura*100)/a.consumo_medio as relacion
		from (
		  select  c.cod_contador, h.lecutra as lectura, avg(h.lecutra) over (partition by c.localidad) as consumo_medio, (avg(h.lecutra) over (partition by c.localidad)*80)/100 porcentaje
		  from    contador c, hist_lectura h
		  where   c.localidad = ciudad
		  and     c.cod_contador = h.cod_contador
		  and     h.fecha >= trunc(to_date(fecha), 'mm')
		  and     h.fecha <= trunc(last_day(to_date(fecha)))
		) a,
		  contrato con 
		where   a.lectura > a.porcentaje
		and     a.cod_contador = con.cod_contador
		and     con.fecha_alta <= to_date(fecha)
		and     con.fecha_baja is null
		order by (a.lectura*100)/a.consumo_medio asc;
		
	BEGIN
		-- Inicializacion de variables
		resultado := 'OK';
        entrada := '< ' || ciudad || '*'|| fecha ||' >';
		-- Comprueba parmetros de entrada
        IF (ciudad IS NULL OR ciudad = ' ') THEN
            RAISE noCiudad;
        END IF;
		IF (fecha IS NULL OR fecha = ' ') THEN
            RAISE noFecha;
        END IF;
		
		DBMS_OUTPUT.PUT_LINE('Listado de contadores que superan el 80%:');
		DBMS_OUTPUT.PUT_LINE('-------------------------------------------------');
		DBMS_OUTPUT.PUT_LINE('Localidad: '||Ciudad);
		DBMS_OUTPUT.PUT_LINE('Fecha: '||fecha);		
		DBMS_OUTPUT.PUT_LINE(' ');		
		DBMS_OUTPUT.PUT_LINE('Contadores');
		DBMS_OUTPUT.PUT_LINE('----------');
		BEGIN
			-- Tratamiento del cursor
			OPEN c_contadores;
			LOOP
				FETCH c_contadores INTO cod_contrato, potencia, tanto_por_cien;						
				EXIT WHEN c_contadores%NOTFOUND;
				DBMS_OUTPUT.PUT_LINE('Cdigo de contrato: '||to_char(cod_contrato));						
				DBMS_OUTPUT.PUT_LINE('Potencia: '||to_char(potencia));		
				DBMS_OUTPUT.PUT_LINE('Tanto por cien: '||to_char(tanto_por_Cien));								
				DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------');
			END LOOP;
			CLOSE c_contadores;
		END;
		-- Ejecucin correcta del procedimiento 
        p_log_insert(procedimento, entrada, salida, resultado);
		
		-- Control de excepcion 
        EXCEPTION
			WHEN noCiudad THEN
				resultado := 'ERROR: <Ciudad> inexistente';
				p_log_insert(procedimento, entrada, salida, resultado);
			WHEN noFecha THEN
				resultado := 'ERROR: <Fecha> inexistente';
				p_log_insert(procedimento, entrada, salida, resultado);	        		
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimento, entrada, salida, resultado);
END p_contadores_80_porc_listado;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_centrales_mas_energia 
	
	Funcionalidad:				Listado de las 10 centrales de distribucin que distribuyen
								mas energia.
								
	Parmetros de entrada: 		
															
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_centrales_mas_energia(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
	CREATE OR REPLACE PROCEDURE p_centrales_mas_energia (
	    resultado OUT NOCOPY Varchar2
	)
IS
    procedimento 	Varchar2(80) := 'p_centrales_mas_energia';
	direccion 		varchar2(40);
	lectura			number(12,2);
	energia_max		number(20,2);
  	salida Varchar2(4000) := ' ';
	err_num NUMBER;
	err_msg Varchar2(255);	 
	entrada Varchar2(4000) := ' ';

	CURSOR c_centrales IS
		select c.direccion, a.lectura, c.energia_max
		from (
		  select    cod_central, lectura  
		  from      hist_energia_emitida 
		  order by  lectura desc
		) a,
		central_distribucion c
		where rownum <= 10
		and   a.cod_central = c.cod_central 
		order by abs(a.lectura) desc ;
		
	BEGIN
		-- Inicializacion de variables
		resultado := 'OK';
       	
		DBMS_OUTPUT.PUT_LINE('Listado de centrales de distribucion que distribuyen mas energia:');
		DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------------------');
	
		BEGIN
			-- Tratamiento del cursor
			OPEN c_centrales;
			LOOP
				FETCH c_centrales INTO direccion, lectura, energia_max;						
				EXIT WHEN c_centrales%NOTFOUND;
				DBMS_OUTPUT.PUT_LINE('Direccin: '||direccion);						
				DBMS_OUTPUT.PUT_LINE('Energa emitida: '||to_char(lectura));		
				DBMS_OUTPUT.PUT_LINE('Energa mxima: '||to_char(energia_max));								
				DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------');
			END LOOP;
			CLOSE c_centrales;
		END;
		-- Ejecucin correcta del procedimiento 
        p_log_insert(procedimento, entrada, salida, resultado);
		
		-- Control de excepcion 
        EXCEPTION			
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimento, entrada, salida, resultado);
END p_centrales_mas_energia;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_lineas_mas_cargadas
	
	Funcionalidad:				Listado de las 10 lneas de comunicacin mas cargadas.
								
	Parmetros de entrada: 		
															
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_lineas_mas_cargadas(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
	CREATE OR REPLACE PROCEDURE p_lineas_mas_cargadas (
	    resultado OUT NOCOPY Varchar2
	)
IS
    procedimento 	Varchar2(80) := 'p_lineas_mas_cargadas';
	cod_linea		number(12,0);
	carga_linea		number;
	energia_ampliar	number;
  	salida 			Varchar2(4000) := ' ';
	err_num 		NUMBER;
	err_msg 		Varchar2(255);	 
	entrada 		Varchar2(4000) := ' ';

	CURSOR c_lineas IS
		select  a.cod_linea, a.porc_carga,  sum(h.lectura) as capacidad_max_recomendada
		from (
		  select  cod_linea, porc_carga
		  from (
			select  cd.cod_linea, (sum(h.lectura)*100)/l.capacidad_max as porc_carga
			from    central_distribucion cd,
					hist_energia_emitida h,
					linea_comunica l 
			where   h.cod_central = cd.cod_central
			and     cd.cod_linea  = l.cod_linea 
			group by  cd.cod_linea , l.capacidad_max 
			order by (sum(h.lectura)*100)/l.capacidad_max desc 
		  )
		  where rownum <= 10
		) a,
		linea_comunica l,
		hist_energia_producida h 
		where a.cod_linea = l.cod_linea
		and   l.cod_central = h.cod_central 
		group by a.cod_linea, a.porc_carga
		order by a.porc_carga desc;
		
	BEGIN
		-- Inicializacion de variables
		resultado := 'OK';
       	
		DBMS_OUTPUT.PUT_LINE('Listado de  las lineas de comunicacin mas cargadas:');
		DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------------------');
	
		BEGIN
			-- Tratamiento del cursor
			OPEN c_lineas;
			LOOP
				FETCH c_lineas INTO cod_linea, carga_linea, energia_ampliar;						
				EXIT WHEN c_lineas%NOTFOUND;
				DBMS_OUTPUT.PUT_LINE('Identificador de la linea: '||to_char(cod_linea));						
				DBMS_OUTPUT.PUT_LINE('Carga de la lnea: '||to_char(carga_linea));		
				DBMS_OUTPUT.PUT_LINE('Energa a ampliar: '||to_char(energia_ampliar));								
				DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------');
			END LOOP;
			CLOSE c_lineas;
		END;
		-- Ejecucin correcta del procedimiento 
        p_log_insert(procedimento, entrada, salida, resultado);
		
		-- Control de excepcion 
        EXCEPTION			
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimento, entrada, salida, resultado);
END p_lineas_mas_cargadas;
/
	

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_clientes_alta_disponibilidad
	
	Funcionalidad:				Listado de los clientes con alta disponibilidad de servicio.
								
	Parmetros de entrada: 		
															
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_clientes_alta_disponibilidad(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
	CREATE OR REPLACE PROCEDURE p_clientes_alta_disponibilidad (
	    resultado OUT NOCOPY Varchar2
	)
IS
    procedimento 	Varchar2(80) := 'p_clientes_alta_disponibilidad';
	salida 			Varchar2(4000) := ' ';
	err_num 		NUMBER;
	err_msg 		Varchar2(255);	 
	entrada 		Varchar2(4000) := ' ';
	dni				varchar2(12);
	contrato		number(12,0);
	modelo_contador	varchar2(20);

	CURSOR c_clientes IS
		select  c.dni_nif as dni , ct.cod_contrato as contrato, cd.modelo as modelo_contador 
		from    cliente c,
				contrato ct ,
				contador cd 
		where   cd.cod_contador in ( 
		  -- el contador que tiene las lineas y las cp  diferentes 
		  select    cc.cod_contador 
		  from      contador_Central cc,
					central_distribucion cd,
					linea_comunica lc 
		  where     cc.cod_contador in(
			-- contadores con mas de una central de distribucion 
			select    cod_contador
			from      contador_central
			group by  cod_contador
			having count(cod_central) > 1
		  )
		  and cc.cod_central = cd.cod_central
		  and cd.cod_linea = lc.cod_linea 
		  group by cc.cod_contador
		  having count( distinct cd.cod_linea) > 1
		  and count(distinct lc.cod_central) > 1
		)
		and  cd.cod_contador = ct.cod_contador 
		and  ct.dni_nif = c.dni_nif;
		
	BEGIN
		-- Inicializacion de variables
		resultado := 'OK';
       	
		DBMS_OUTPUT.PUT_LINE('Listado de los clientes con alta disponibilidad:');
		DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------------------');
	
		BEGIN
			-- Tratamiento del cursor
			OPEN c_clientes;
			LOOP
				FETCH c_clientes INTO dni, contrato, modelo_contador;						
				EXIT WHEN c_clientes%NOTFOUND;
				DBMS_OUTPUT.PUT_LINE('NIF/DNI del cliente: '||dni);						
				DBMS_OUTPUT.PUT_LINE('Contrato: '||to_char(contrato));		
				DBMS_OUTPUT.PUT_LINE('Modelo del contador: '||to_char(modelo_contador));								
				DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------');
			END LOOP;
			CLOSE c_clientes;
		END;
		-- Ejecucin correcta del procedimiento 
        p_log_insert(procedimento, entrada, salida, resultado);
		
		-- Control de excepcion 
        EXCEPTION			
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimento, entrada, salida, resultado);
END p_clientes_alta_disponibilidad;
/	


/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_central_produccion_consumo
	
	Funcionalidad:				Produccion y consumo de una central determinada para un 
								periodo de tiempo
								
	Parmetros de entrada: 		
								Cdigo de la central
								Fecha de inicio
								Fecha de fin
															
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_central_produccion_consumo(3, '01/12/2011','31/12/2011',RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
	create or replace
PROCEDURE p_central_produccion_consumo (
		central IN central_produccion.cod_central%TYPE,
		fecha_ini IN varchar2, 
		fecha_fin IN varchar2, 
	    resultado OUT NOCOPY Varchar2
	)
IS
    procedimento 	Varchar2(80) := 'p_central_produccion_consumo';
	salida 			Varchar2(4000) := ' ';
	err_num 		NUMBER;
	err_msg 		Varchar2(255);	 
	entrada 		Varchar2(4000) := ' ';
	consumo			number(10,2);
	produccion		number(10,2);
	noCentral EXCEPTION;
	noFecha EXCEPTION;
	
	CURSOR c_central IS
		-- consumo contadores de esta central  para esas fechas
		select  sum(l.lecutra) as consumo_contadores, sum(e.lectura) as energia_producida 
		from    linea_comunica lc ,
				central_distribucion cd,
				contador_central cc,
				hist_lectura l,
				hist_energia_producida e 
		where   lc.cod_central = central
		and     cd.cod_linea   = lc.cod_linea
		and     cc.cod_central  = cd.cod_central 
		and     l.cod_contador = cc.cod_contador
		and     l.fecha >= to_date(fecha_ini)
		and     l.fecha <= to_date(fecha_fin)
		and     e.cod_central = lc.cod_central
		and     e.fecha >= to_date(fecha_ini)
		and     e.fecha <= to_date(fecha_fin);
		
	BEGIN
		-- Inicializacion de variables
		resultado := 'OK';
       	
		entrada := '< ' || to_char(central) || '*'|| to_char(fecha_ini) ||'*'|| to_char(fecha_fin) ||' >';
		-- Comprueba parmetros de entrada
        IF (central IS NULL OR central = 0) THEN
            RAISE noCentral;
        END IF;
		IF (fecha_ini IS NULL OR fecha_ini = ' ') THEN
            RAISE noFecha;
        END IF;
		IF (fecha_fin IS NULL OR fecha_fin = ' ') THEN
            RAISE noFecha;
        END IF;
		
		DBMS_OUTPUT.PUT_LINE('Produccion y consumo para la central');
		DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------------------');
	
		DBMS_OUTPUT.PUT_LINE('Central de produccin: '||to_char(central));
		DBMS_OUTPUT.PUT_LINE('Fecha inicial: '||to_char(fecha_ini));
		DBMS_OUTPUT.PUT_LINE('Fecha final: '||to_char(fecha_fin));
		DBMS_OUTPUT.PUT_LINE(' ');
			
		BEGIN
			-- Tratamiento del cursor
			OPEN c_central;
     
			LOOP
				FETCH c_central INTO consumo, produccion;						
				EXIT WHEN c_central%NOTFOUND;
				DBMS_OUTPUT.PUT_LINE('Consumo de los contadores asociados: '||to_char(consumo));						
				DBMS_OUTPUT.PUT_LINE('Produccin: '||to_char(produccion));		
				DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------');
			END LOOP;
			CLOSE c_central;
		END;
			-- Control de excepcion 
        EXCEPTION		
			WHEN noCentral THEN
				resultado := 'ERROR: <Central> inexistente';
				p_log_insert(procedimento, entrada, salida, resultado);
			WHEN noFecha THEN
				resultado := 'ERROR: <Fecha> inexistente';
				p_log_insert(procedimento, entrada, salida, resultado);	        		
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimento, entrada, salida, resultado);
END p_central_produccion_consumo;
/


/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_porc_lecturas
	
	Funcionalidad:				Porcentaje de lecturas efectuadas de forma presencial o 
								de forma telemtica en un periodo de tiempo
								
	Parmetros de entrada: 		
								Fecha de inicio
								Fecha de fin
															
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_porc_lecturas('01/12/2011','31/12/2011',RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
	CREATE OR REPLACE PROCEDURE p_porc_lecturas (
		fecha_ini IN date, 
		fecha_fin IN date, 
	    resultado OUT NOCOPY Varchar2
	)
IS
    procedimento 	Varchar2(80) := 'p_porc_lecturas';
	salida 			Varchar2(4000) := ' ';
	err_num 		NUMBER;
	err_msg 		Varchar2(255);	 
	entrada 		Varchar2(4000) := ' ';
	noFecha 		EXCEPTION;
	presencial		number;
	telematica		number;
	
	CURSOR c_lecturas IS
		
		select  (a.sum_presencial*100)/(a.sum_presencial+b.sum_telematica) as porcentaje_presencial, (b.sum_telematica*100)/(a.sum_presencial+b.sum_telematica) as porcentaje_telematica
		from (
		  select  nvl(count (e.cod_contador), 0) as sum_presencial
		  from    hist_lectura e
		  where   e.fecha >= to_date(fecha_ini)
		  and     e.fecha <= to_date(fecha_fin) 
		  and     e.modo = 'P'
		  ) a,
		  (
		  select  nvl(count (cod_contador), 0) as sum_telematica 
		  from    hist_lectura
		  where   fecha >= to_date(fecha_ini)
		  and     fecha <= to_date(fecha_fin) 
		  and     modo = 'T'
		  )b;
		
	BEGIN
		-- Inicializacion de variables
		resultado := 'OK';
       	entrada := '< ' || to_char(fecha_ini) ||'*'|| to_char(fecha_fin) ||' >';
		-- Comprueba parmetros de entrada
       	IF (fecha_ini IS NULL OR fecha_ini = ' ') THEN
            RAISE noFecha;
        END IF;
		IF (fecha_fin IS NULL OR fecha_fin = ' ') THEN
            RAISE noFecha;
        END IF;
				
		DBMS_OUTPUT.PUT_LINE('Porcentaje de lecturas presenciales y telemticas en un periodo de tiempo:');
		DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------------------');
	
		DBMS_OUTPUT.PUT_LINE('Fecha inicial: '||to_char(fecha_ini));
		DBMS_OUTPUT.PUT_LINE('Fecha final: '||to_char(fecha_fin));
		DBMS_OUTPUT.PUT_LINE(' ');
			
		BEGIN
			-- Tratamiento del cursor
			OPEN c_lecturas;
			LOOP
				FETCH c_lecturas INTO presencial, telematica;						
				EXIT WHEN c_lecturas%NOTFOUND;
				DBMS_OUTPUT.PUT_LINE('Lecturas presenciales: '||to_char(presencial));						
				DBMS_OUTPUT.PUT_LINE('Lecturas telemticas: '||to_char(telematica));		
				DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------');
			END LOOP;
			CLOSE c_lecturas;
		END;
		-- Ejecucin correcta del procedimiento 
        p_log_insert(procedimento, entrada, salida, resultado);
		
		-- Control de excepcion 
        EXCEPTION
			WHEN noFecha THEN
				resultado := 'ERROR: <Fecha> inexistente';
				p_log_insert(procedimento, entrada, salida, resultado);	  		
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimento, entrada, salida, resultado);
END p_porc_lecturas;
/	

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimiento: 	p_contadores_antiguedad
	
	Funcionalidad:				Listado de contadores con un determinado nmero de aos
								de antiguedad
								
	Parmetros de entrada: 		
								Aos
															
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_contadores_antiguedad(12, RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
	CREATE OR REPLACE PROCEDURE p_contadores_antiguedad (
		anos IN number, 
	    resultado OUT NOCOPY Varchar2
	)
IS
    procedimento 	Varchar2(80) := 'p_contadores_antiguedad';
	salida 			Varchar2(4000) := ' ';
	err_num 		NUMBER;
	err_msg 		Varchar2(255);	 
	entrada 		Varchar2(4000) := ' ';
	noAnos	 		EXCEPTION;
	cod_contador	contador.cod_contador%TYPE;
		
	CURSOR c_contadores IS
		
		select  cod_contador 
		from    modelo_contador m,
				contador c 
		where   to_char(sysdate,'yyyy') - m.anyo_fabricacion = anos
		and     m.modelo = c.modelo;
		
	BEGIN
		-- Inicializacion de variables
		resultado := 'OK';
       	entrada := '< ' || to_char(anos) ||'*'||' >';
		-- Comprueba parmetros de entrada
       	IF (anos IS NULL ) THEN
            RAISE noAnos;
        END IF;
						
		DBMS_OUTPUT.PUT_LINE('Listado de contadores con una antiguedad de:');
		DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------------------');
	
		DBMS_OUTPUT.PUT_LINE('Aos: '||to_char(anos));
		DBMS_OUTPUT.PUT_LINE(' ');
			
		BEGIN
			-- Tratamiento del cursor
			OPEN c_contadores;
			LOOP
				FETCH c_contadores INTO cod_contador;						
				EXIT WHEN c_contadores%NOTFOUND;
				DBMS_OUTPUT.PUT_LINE('Contador: '||to_char(cod_contador));						
				DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------');
			END LOOP;
			CLOSE c_contadores;
		END;
		-- Ejecucin correcta del procedimiento 
        p_log_insert(procedimento, entrada, salida, resultado);
		
		-- Control de excepcion 
        EXCEPTION
			WHEN noAnos THEN
				resultado := 'ERROR: <Aos> inexistente';
				p_log_insert(procedimento, entrada, salida, resultado);	  		
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimento, entrada, salida, resultado);
END p_contadores_antiguedad;
/	