/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimientoo: 	p_e1_listado
	
	Funcionalidad:				Saca el listado de las estadisticas de la tabla e1.
								Dada una central de produccin, el consumo de los contadores de esa central
								
	Parmetros de entrada: 		
								central_produccion
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e1_listado(2,RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e1_listado (
	cod_cen IN central_produccion.cod_central%TYPE,
	resultado OUT NOCOPY Varchar2
	)
IS
    procedimiento Varchar2(80) := 'p_e1_listado';
    entrada Varchar2(4000) := ' ';
    salida Varchar2(4000) := ' ';
    err_msg Varchar2(255);		
    err_num number;
    noCentral EXCEPTION;
    c_contador number;
    acumula number;

	CURSOR c_contadores IS
		select 	cod_contador, acumulador
		from 	e1
		where 	cod_central = cod_cen;
    
BEGIN
		-- Inicializacin de variables
		resultado := 'OK';
    entrada := '<' || to_char(cod_cen) || '>';
		
        -- Comprobacin parmetros de entrada
    IF (cod_cen IS NULL OR cod_cen = 0) THEN
        RAISE noCentral;
    END IF;
       		
		BEGIN
			DBMS_OUTPUT.PUT_LINE('Listado E1 - Contadores y consumo de central de produccin');
			DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------------');
			DBMS_OUTPUT.PUT_LINE(' ');
		END;
		
        -- Tratamiento del cursor
		OPEN c_contadores;
		LOOP
			FETCH c_contadores INTO c_contador, acumula;						
			EXIT WHEN c_contadores%NOTFOUND;
			
			DBMS_OUTPUT.PUT_LINE('--------------------------------');
			DBMS_OUTPUT.PUT_LINE('Cdigo contador: '||to_char(c_contador));
			DBMS_OUTPUT.PUT_LINE('Acumulador: '||to_char(acumula));		
			DBMS_OUTPUT.PUT_LINE('--------------------------------');
						
		END LOOP;
		CLOSE c_contadores;		
		
		-- Execuci correcta del procediment
        p_log_insert(procedimiento, entrada, salida, resultado);
        
		-- Control d'excepcions
        EXCEPTION
			WHEN noCentral THEN
				resultado := 'ERROR: <codigo de central> inexistente';
				p_log_insert(procedimiento, entrada, salida, resultado);
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimiento, entrada, salida, resultado);
END p_e1_listado;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimientoo: 	p_e2_listado
	
	Funcionalidad:				Saca el listado de las estadisticas de la tabla e2.
								Dada una lnea de comunicacin y un ao, el valor medio de la energia consumida.
								
	Parmetros de entrada: 		
								linea_comunicacion
								ao
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e2_listado(2,2012,RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e2_listado (
	c_linea IN linea_comunica.cod_linea%TYPE,
	ano in number,
	resultado OUT NOCOPY Varchar2
	)
IS
    procedimiento Varchar2(80) := 'p_e2_listado';
    entrada Varchar2(4000) := ' ';
    salida Varchar2(4000) := ' ';
    err_msg Varchar2(255);		
    err_num number;
    noLinea EXCEPTION;
	noAno EXCEPTION;
	valor number;
BEGIN
	
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<' || to_char(c_linea) || '><'|| to_char(ano) ||'>';
		
    -- Comprobacin parmetros de entrada
    IF (c_linea IS NULL OR c_linea = 0) THEN
        RAISE noLinea;
    END IF;
	
	IF (ano IS NULL OR ano = 0) THEN
        RAISE noAno;
    END IF;
       		
	DBMS_OUTPUT.PUT_LINE('Listado E2 - Valor medio de energia consumida de una lnea en un ao');
	DBMS_OUTPUT.PUT_LINE('--------------------------------------------------------------------');
	DBMS_OUTPUT.PUT_LINE(' Lnea: ' || to_char(c_linea));
	DBMS_OUTPUT.PUT_LINE(' Ao: ' || to_char(ano));
		
	select 	valor_medio
	into	valor
	from 	e2
	where 	cod_linea = c_linea
	and		anyo = ano;
	
	DBMS_OUTPUT.PUT_LINE(' Valor medio: ' || to_char(valor));
	
	-- Execuci correcta del procediment
	p_log_insert(procedimiento, entrada, salida, resultado);
	
	-- Control d'excepcions
	EXCEPTION
		WHEN noLinea THEN
			resultado := 'ERROR: <codigo de linea> inexistente';
			p_log_insert(procedimiento, entrada, salida, resultado);
		WHEN noAno THEN
			resultado := 'ERROR: <ao> inexistente';
			p_log_insert(procedimiento, entrada, salida, resultado);			
		WHEN OTHERS THEN
			err_num := SQLCODE;
			err_msg := SQLERRM;
			resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
			p_log_insert(procedimiento, entrada, salida, resultado);
END p_e2_listado;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimientoo: 	p_e3_listado
	
	Funcionalidad:				Saca la linea que mas cargada a nivel de energia consumida
								
	Parmetros de entrada: 		
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e3_listado(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e3_listado (
	ano in number,
	resultado OUT NOCOPY Varchar2
	)
IS
    procedimiento Varchar2(80) := 'p_e3_listado';
    entrada Varchar2(4000) := ' ';
    salida Varchar2(4000) := ' ';
    err_msg Varchar2(255);		
    err_num number;
	c_linea NUMBER;
	
BEGIN
	
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<>';
		     		
	DBMS_OUTPUT.PUT_LINE('Listado E3 - Lnea mas cargada.');
	DBMS_OUTPUT.PUT_LINE('--------------------------------------------------------------------');
			
	select 	cod_linea
	into	c_linea
	from 	e3;
	
	DBMS_OUTPUT.PUT_LINE(' Lnea: ' || to_char(c_linea));
	
	-- Execuci correcta del procediment
	p_log_insert(procedimiento, entrada, salida, resultado);
	
	-- Control d'excepcions
	EXCEPTION
		WHEN OTHERS THEN
			err_num := SQLCODE;
			err_msg := SQLERRM;
			resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
			p_log_insert(procedimiento, entrada, salida, resultado);
END p_e3_listado;
/
/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimientoo: 	p_e4_listado
	
	Funcionalidad:				Saca el porcentaje de lineas que han superado el 50% de su
								capacidad para un ao determinado
								
	Parmetros de entrada: 		
								ao 
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e4_listado(2012, RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e4_listado (
	anio in number,
	resultado OUT NOCOPY Varchar2
	)
IS
    procedimiento Varchar2(80) := 'p_e4_listado';
    entrada Varchar2(4000) := ' ';
    salida Varchar2(4000) := ' ';
    err_msg Varchar2(255);		
    err_num number;
	porcentaje number;
	noAno EXCEPTION;	
	
BEGIN
	
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<' || to_char(anio) || '>';
		
    -- Comprobacin parmetros de entrada
    IF (anio IS NULL OR anio = 0) THEN
        RAISE noAno;
    END IF;
       		
	BEGIN
		DBMS_OUTPUT.PUT_LINE('Listado E4 - Porcentaje de lneas que superan el 50% de su capacidad');
		DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------------');
		DBMS_OUTPUT.PUT_LINE(' Ao: ' || to_char(anio));
		DBMS_OUTPUT.PUT_LINE(' ');
	END;
	
	select 	porcentaje_linea
	into	porcentaje
	from 	e4
	where	anyo = anio;
	
	DBMS_OUTPUT.PUT_LINE(' Porcentaje de lineas: ' || to_char(porcentaje));
	
	
	-- Execuci correcta del procediment
	p_log_insert(procedimiento, entrada, salida, resultado);
	
	-- Control d'excepcions
	EXCEPTION
		WHEN noAno THEN
			resultado := 'ERROR: <ao> inexistente';
			p_log_insert(procedimiento, entrada, salida, resultado);
		WHEN OTHERS THEN
			err_num := SQLCODE;
			err_msg := SQLERRM;
			resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
			p_log_insert(procedimiento, entrada, salida, resultado);
END p_e4_listado;
/

/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimientoo: 	p_e5_listado
	
	Funcionalidad:				Saca el nmero de centrales de produccion que generan 
								menos del 30% del total de esta en un ao
								
	Parmetros de entrada: 		
								ao 
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e5_listado(2012, RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e5_listado (
	anio in number,
	resultado OUT NOCOPY Varchar2
	)
IS
    procedimiento Varchar2(80) := 'p_e5_listado';
    entrada Varchar2(4000) := ' ';
    salida Varchar2(4000) := ' ';
    err_msg Varchar2(255);		
    err_num number;
	num_centrales number;
	noAno EXCEPTION;	
	
BEGIN
	
	-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<' || to_char(anio) || '>';
		
    -- Comprobacin parmetros de entrada
    IF (anio IS NULL OR anio = 0) THEN
        RAISE noAno;
    END IF;
       		
	BEGIN
		DBMS_OUTPUT.PUT_LINE('Listado E5 - Nmero de centrales de produccin que generan menos del 30% de la produccin total');
		DBMS_OUTPUT.PUT_LINE('-------------------------------------------------------------------------------------------------');
		DBMS_OUTPUT.PUT_LINE(' Ao: ' || to_char(anio));
		DBMS_OUTPUT.PUT_LINE(' ');
	END;
	
	select 	num_centrales_produccion 
	into	num_centrales
	from 	e5
	where	anyo = anio;
	
	DBMS_OUTPUT.PUT_LINE(' Nmero de centrales: ' || to_char(num_centrales));
	
	
	-- Execuci correcta del procediment
	p_log_insert(procedimiento, entrada, salida, resultado);
	
	-- Control d'excepcions
	EXCEPTION
		WHEN noAno THEN
			resultado := 'ERROR: <ao> inexistente';
			p_log_insert(procedimiento, entrada, salida, resultado);
		WHEN OTHERS THEN
			err_num := SQLCODE;
			err_msg := SQLERRM;
			resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
			p_log_insert(procedimiento, entrada, salida, resultado);
END p_e5_listado;
/
/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimientoo: 	p_e6_listado
	
	Funcionalidad:				Saca el listado de las estadisticas de la tabla e6.
								El top 10 de contadores con mas consumo histricamente.
								
	Parmetros de entrada: 		
								
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e6_listado(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e6_listado (
	resultado OUT NOCOPY Varchar2
	)
IS
    procedimiento Varchar2(80) := 'p_e6_listado';
    entrada Varchar2(4000) := ' ';
    salida Varchar2(4000) := ' ';
    err_msg Varchar2(255);		
    err_num number;
    c_contador number;
    
	CURSOR c_contadores IS
		select 	cod_contador 
		from 	e6;
		    
BEGIN
		-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<>';
 
    
	DBMS_OUTPUT.PUT_LINE('Listado E6 - Top 10 de contadores con mas consumo:');
	DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------------');
	DBMS_OUTPUT.PUT_LINE(' ');

		
       -- Tratamiento del cursor
		OPEN c_contadores;
		LOOP
			FETCH c_contadores INTO c_contador;						
			EXIT WHEN c_contadores%NOTFOUND;
			
			DBMS_OUTPUT.PUT_LINE('--------------------------------');
			DBMS_OUTPUT.PUT_LINE('Cdigo contador: '||to_char(c_contador));
			DBMS_OUTPUT.PUT_LINE('--------------------------------');
						
		END LOOP;
		CLOSE c_contadores;		
		
		-- Execuci correcta del procediment
        p_log_insert(procedimiento, entrada, salida, resultado);
        
		-- Control d'excepcions
        EXCEPTION
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimiento, entrada, salida, resultado);
END p_e6_listado;
/
/*********************************************************************************
	Fecha de creacion: 			01/05/2012
	
	Usuario de creacion:		uoc
	
	Nombre del procedimientoo: 	p_e7_listado
	
	Funcionalidad:				Saca el listado de las estadisticas de la tabla e7.
								Consumo medio de todos los clientes.
								
	Parmetros de entrada: 		
								
								
	Parmetros de salida: 		
								resultado(RSP)
							
	Procedimentos que ejecuta: 	
								p_log_insert
								
	Ejemplo de uso:				
								p_e7_listado(RSP);
	
	MODIFICACIONES POSTERIORES:
								
	*********************************************************************************/
create or replace
PROCEDURE p_e7_listado (
	resultado OUT NOCOPY Varchar2
	)
IS
    procedimiento Varchar2(80) := 'p_e7_listado';
    entrada Varchar2(4000) := ' ';
    salida Varchar2(4000) := ' ';
    err_msg Varchar2(255);		
    err_num number;
    consumo number;
	dni varchar2(12);
    
	CURSOR c_clientes IS
		select 	dni_nif, consumo_medio  
		from 	e7;
		    
BEGIN
		-- Inicializacin de variables
	resultado := 'OK';
    entrada := '<>';
 
    
	DBMS_OUTPUT.PUT_LINE('Listado E7 - Consumo medio de todos los clientes:');
	DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------------');
	DBMS_OUTPUT.PUT_LINE(' ');

		
       -- Tratamiento del cursor
		OPEN c_clientes;
		LOOP
			FETCH c_clientes INTO dni, consumo;						
			EXIT WHEN c_clientes%NOTFOUND;
			
			DBMS_OUTPUT.PUT_LINE('--------------------------------');
			DBMS_OUTPUT.PUT_LINE('Dni/Nif del cliente: '||dni);
			DBMS_OUTPUT.PUT_LINE('Consumo medio '||to_char(consumo));
			DBMS_OUTPUT.PUT_LINE('--------------------------------');
						
		END LOOP;
		CLOSE c_clientes;		
		
		-- Execuci correcta del procediment
        p_log_insert(procedimiento, entrada, salida, resultado);
        
		-- Control d'excepcions
        EXCEPTION
			WHEN OTHERS THEN
				err_num := SQLCODE;
				err_msg := SQLERRM;
				resultado := 'ERROR: ' || TO_CHAR(err_num) || '->' || err_msg ;
				p_log_insert(procedimiento, entrada, salida, resultado);
END p_e7_listado;
/
